#
# spec file for package python-google-api-python-client
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-google-api-python-client
Version:        2.154.0
Release:        1.1
Summary:        Google APIs Python Client
License:        Apache-2.0
URL:            https://github.com/google/google-api-python-client
Source:         https://files.pythonhosted.org/packages/source/g/google_api_python_client/google_api_python_client-%{version}.tar.gz
BuildRequires:  %{python_module google-api-core >= 1.31.5}
BuildRequires:  %{python_module google-auth >= 1.32.0}
BuildRequires:  %{python_module google-auth-httplib2 >= 0.2.0}
BuildRequires:  %{python_module httplib2 >= 0.19.0}
BuildRequires:  %{python_module parameterized}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module uritemplate  >= 3.0.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-google-api-core >= 1.31.5
Requires:       python-google-auth >= 1.32.0
Requires:       python-google-auth-httplib2 >= 0.2.0
Requires:       python-httplib2 >= 0.19.0
Requires:       python-uritemplate >= 3.0.1
# Package renamed in SLE 12, do not remove Provides, Obsolete directives
# until after SLE 12 EOL
Provides:       google-api-python-client = %{version}
Obsoletes:      google-api-python-client < %{version}
BuildArch:      noarch
%python_subpackages

%description
Google APIs Client Library for Python

%prep
%autosetup -p1 -n google_api_python_client-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# DiscoveryErrors::test_credentials_and_credentials_file_mutually_exclusive fails with "socket.gaierror: [Errno -3] Temporary failure in name resolution"
donttest="test_credentials_and_credentials_file_mutually_exclusive"
# don't test deprecated oaut2client usage
donttest="$donttest or TestAuthWithOAuth2Client or test_oauth2client_crendentials"
# Both test_client_options_universe_configured_with_mtls and test_universe_env_var_configured_with_mtls require internet connection
donttest="$donttest or test_client_options_universe_configured_with_mtls or test_universe_env_var_configured_with_mtls"
# test_http.py uses mocked Credentials class and API from deprecated oauth2client
%pytest --ignore=samples --ignore tests/test_http.py -k "not ($donttest)"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/apiclient
%{python_sitelib}/googleapiclient
%{python_sitelib}/google_api_python_client-%{version}.dist-info

%changelog
* Thu Dec  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.154.0
  * **aiplatform:** Update the api
  * **androidenterprise:** Update the api
  * **beyondcorp:** Update the api
  * **cloudsearch:** Update the api
  * **connectors:** Update the api
  * **contactcenterinsights:** Update the api
  * **datamigration:** Update the api
  * **deploymentmanager:** Update the api
  * **digitalassetlinks:** Update the api
  * **discoveryengine:** Update the api
  * **drive:** Update the api
  * **firebaseappdistribution:** Update the api
  * **firebasestorage:** Update the api
  * **gkehub:** Update the api
  * **gkeonprem:** Update the api
  * **netapp:** Update the api
  * **networkmanagement:** Update the api
  * **networksecurity:** Update the api
  * **networkservices:** Update the api
  * **securitycenter:** Update the api
  * **servicemanagement:** Update the api
  * **servicenetworking:** Update the api
  * **sqladmin:** Update the api
  * **storage:** Update the api
  * **sts:** Update the api
  * **walletobjects:** Update the api
  * **datalineage:** Update the api
  * **speech:** Update the api
- from version 2.153.0
  * **accesscontextmanager:** Update the api
  * **calendar:** Update the api
  * **chat:** Update the api
  * **cloudchannel:** Update the api
  * **compute:** Update the api
  * **container:** Update the api
  * **dataplex:** Update the api
  * **deploymentmanager:** Update the api
  * **discoveryengine:** Update the api
  * **fcm:** Update the api
  * **firebaseml:** Update the api
  * **integrations:** Update the api
  * **networkconnectivity:** Update the api
  * **paymentsresellersubscription:** Update the api
  * **places:** Update the api
  * **searchads360:** Update the api
  * **servicenetworking:** Update the api
  * **testing:** Update the api
- from version 2.152.0
  * **accesscontextmanager:** Update the api
  * **admin:** Update the api
  * **aiplatform:** Update the api
  * **analyticshub:** Update the api
  * **beyondcorp:** Update the api
  * **clouddeploy:** Update the api
  * **compute:** Update the api
  * **container:** Update the api
  * **dataflow:** Update the api
  * **datastream:** Update the api
  * **developerconnect:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **firebaseappdistribution:** Update the api
  * **gkehub:** Update the api
  * **gkeonprem:** Update the api
  * **migrationcenter:** Update the api
  * **networkmanagement:** Update the api
  * **serviceusage:** Update the api
  * **tpu:** Update the api
  * **youtube:** Update the api
  * **translate:** Update the api
- from version 2.151.0
  * **accesscontextmanager:** Update the api
  * **aiplatform:** Update the api
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **androidenterprise:** Update the api
  * **androidpublisher:** Update the api
  * **apigee:** Update the api
  * **apikeys:** Update the api
  * **artifactregistry:** Update the api
  * **backupdr:** Update the api
  * **beyondcorp:** Update the api
  * **bigqueryreservation:** Update the api
  * **bigquery:** Update the api
  * **chat:** Update the api
  * **checks:** Update the api
  * **chromemanagement:** Update the api
  * **cloudbilling:** Update the api
  * **cloudbuild:** Update the api
  * **cloudchannel:** Update the api
  * **cloudcontrolspartner:** Update the api
  * **clouddeploy:** Update the api
  * **cloudidentity:** Update the api
  * **compute:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **contactcenterinsights:** Update the api
  * **container:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **datacatalog:** Update the api
  * **dataform:** Update the api
  * **datalineage:** Update the api
  * **datamigration:** Update the api
  * **dataplex:** Update the api
  * **datastore:** Update the api
  * **developerconnect:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **discoveryengine:** Update the api
  * **displayvideo:** Update the api
  * **documentai:** Update the api
  * **eventarc:** Update the api
  * **file:** Update the api
  * **firebaseappdistribution:** Update the api
  * **firebaseappdistribution:** Update the api
  * **firebaseml:** Update the api
  * **gkehub:** Update the api
  * **iamcredentials:** Update the api
  * **identitytoolkit:** Update the api
  * **identitytoolkit:** Update the api
  * **integrations:** Update the api
  * **merchantapi:** Update the api
  * **networkconnectivity:** Update the api
  * **networkmanagement:** Update the api
  * **networkservices:** Update the api
  * **oracledatabase:** Update the api
  * **orgpolicy:** Update the api
  * **osconfig:** Update the api
  * **places:** Update the api
  * **places:** Update the api
  * **recaptchaenterprise:** Update the api
  * **recommender:** Update the api
  * **redis:** Update the api
  * **retail:** Update the api
  * **retail:** Update the api
  * **run:** Update the api
  * **securitycenter:** Update the api
  * **securitycenter:** Update the api
  * **spanner:** Update the api
  * **spanner:** Update the api
  * **speech:** Update the api
  * **texttospeech:** Update the api
  * **tpu:** Update the api
  * **vmmigration:** Update the api
  * **walletobjects:** Update the api
  * **workloadmanager:** Update the api
  * **workstations:** Update the api
  * **youtube:** Update the api
  * **composer:** Update the api
  * **workspaceevents:** Update the api
- from version 2.150.0
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **appengine:** Update the api
  * **apphub:** Update the api
  * **assuredworkloads:** Update the api
  * **backupdr:** Update the api
  * **beyondcorp:** Update the api
  * **compute:** Update the api
  * **container:** Update the api
  * **datamigration:** Update the api
  * **drive:** Update the api
  * **firebaseml:** Update the api
  * **gkehub:** Update the api
  * **migrationcenter:** Update the api
  * **monitoring:** Update the api
  * **playdeveloperreporting:** Update the api
  * **retail:** Update the api
  * **securitycenter:** Update the api
  * **sqladmin:** Update the api
  * **storage:** Update the api
  * **workloadmanager:** Update the api
  * **youtube:** Update the api
  * **composer:** Update the api
  * **spanner:** Update the api
* Mon Oct 28 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.149.0
  * **androidpublisher:** Update the api
  * **apigee:** Update the api
  * **artifactregistry:** Update the api
  * **backupdr:** Update the api
  * **beyondcorp:** Update the api
  * **bigquery:** Update the api
  * **chat:** Update the api
  * **clouddeploy:** Update the api
  * **container:** Update the api
  * **datamigration:** Update the api
  * **dataproc:** Update the api
  * **discoveryengine:** Update the api
  * **firebaseappdistribution:** Update the api
  * **firebaseml:** Update the api
  * **language:** Update the api
  * **merchantapi:** Update the api
  * **migrationcenter:** Update the api
  * **monitoring:** Update the api
  * **run:** Update the api
  * **searchads360:** Update the api
  * **securitycenter:** Update the api
  * **texttospeech:** Update the api
  * **developerconnect:** Update the api
  * **factchecktools:** Update the api
- from version 2.148.0
  * **accesscontextmanager:** Update the api
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **androidmanagement:** Update the api
  * **artifactregistry:** Update the api
  * **assuredworkloads:** Update the api
  * **backupdr:** Update the api
  * **bigtableadmin:** Update the api
  * **clouddeploy:** Update the api
  * **cloudscheduler:** Update the api
  * **connectors:** Update the api
  * **contactcenterinsights:** Update the api
  * **developerconnect:** Update the api
  * **dfareporting:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **firebaseml:** Update the api
  * **integrations:** Update the api
  * **memcache:** Update the api
  * **merchantapi:** Update the api
  * **networkconnectivity:** Update the api
  * **networkmanagement:** Update the api
  * **networksecurity:** Update the api
  * **networkservices:** Update the api
  * **pubsub:** Update the api
  * **redis:** Update the api
  * **retail:** Update the api
  * **securitycenter:** Update the api
  * **serviceconsumermanagement:** Update the api
  * **servicemanagement:** Update the api
  * **serviceusage:** Update the api
  * **sqladmin:** Update the api
  * **storage:** Update the api
  * **walletobjects:** Update the api
  * **bigquerydatatransfer:** Update the api
  * **bigqueryreservation:** Update the api
  * **places:** Update the api
  * **spanner:** Update the api
* Thu Sep 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.147.0
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **androiddeviceprovisioning:** Update the api
  * **backupdr:** Update the api
  * **bigquerydatatransfer:** Update the api
  * **chromeuxreport:** Update the api
  * **composer:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **container:** Update the api
  * **datamigration:** Update the api
  * **dataplex:** Update the api
  * **discoveryengine:** Update the api
  * **dlp:** Update the api
  * **eventarc:** Update the api
  * **firebaseml:** Update the api
  * **integrations:** Update the api
  * **merchantapi:** Update the api
  * **networkmanagement:** Update the api
  * **networkservices:** Update the api
  * **places:** Update the api
  * **redis:** Update the api
  * **retail:** Update the api
  * **run:** Update the api
  * **securitycenter:** Update the api
  * **servicenetworking:** Update the api
  * **spanner:** Update the api
  * **storage:** Update the api
  * **testing:** Update the api
  * **tpu:** Update the api
  * **walletobjects:** Update the api
  * **youtube:** Update the api
  * **androidpublisher:** Update the api
  * **cloudkms:** Update the api
- from version 2.146.0
  * **accesscontextmanager:** Update the api
  * **aiplatform:** Update the api
  * **apigee:** Update the api
  * **beyondcorp:** Update the api
  * **bigtableadmin:** Update the api
  * **civicinfo:** Update the api
  * **cloudchannel:** Update the api
  * **cloudfunctions:** Update the api
  * **compute:** Update the api
  * **contactcenterinsights:** Update the api
  * **container:** Update the api
  * **css:** Update the api
  * **datastream:** Update the api
  * **discoveryengine:** Update the api
  * **documentai:** Update the api
  * **firebaseml:** Update the api
  * **firebase:** Update the api
  * **firestore:** Update the api
  * **gkehub:** Update the api
  * **logging:** Update the api
  * **looker:** Update the api
  * **merchantapi:** Update the api
  * **networkconnectivity:** Update the api
  * **networkmanagement:** Update the api
  * **serviceconsumermanagement:** Update the api
  * **serviceusage:** Update the api
  * **vpcaccess:** Update the api
  * **walletobjects:** Update the api
  * **bigquery:** Update the api
  * **chat:** Update the api
  * **translate:** Update the api
* Tue Sep  3 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.143.0
  * **accessapproval:** Update the api
  * **androidmanagement:** Update the api
  * **androidpublisher:** Update the api
  * **assuredworkloads:** Update the api
  * **backupdr:** Update the api
  * **batch:** Update the api
  * **chat:** Update the api
  * **cloudasset:** Update the api
  * **cloudkms:** Update the api
  * **connectors:** Update the api
  * **containeranalysis:** Update the api
  * **container:** Update the api
  * **customsearch:** Update the api
  * **dataflow:** Update the api
  * **dataplex:** Update the api
  * **dfareporting:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **firebasedynamiclinks:** Update the api
  * **firebaseml:** Update the api
  * **gkeonprem:** Update the api
  * **looker:** Update the api
  * **merchantapi:** Update the api
  * **migrationcenter:** Update the api
  * **monitoring:** Update the api
  * **networkmanagement:** Update the api
  * **networkservices:** Update the api
  * **notebooks:** Update the api
  * **redis:** Update the api
  * **searchads360:** Update the api
  * **servicenetworking:** Update the api
  * **solar:** Update the api
  * **sqladmin:** Update the api
  * **storage:** Update the api
  * **translate:** Update the api
  * **workflowexecutions:** Update the api
  * **workflows:** Update the api
  * **workstations:** Update the api
- from version 2.142.0
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **androidpublisher:** Update the api
  * **backupdr:** Update the api
  * **beyondcorp:** Update the api
  * **bigquery:** Update the api
  * **bigtableadmin:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **container:** Update the api
  * **dataflow:** Update the api
  * **datamigration:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **displayvideo:** Update the api
  * **dlp:** Update the api
  * **documentai:** Update the api
  * **gkehub:** Update the api
  * **healthcare:** Update the api
  * **integrations:** Update the api
  * **manufacturers:** Update the api
  * **migrationcenter:** Update the api
  * **networkconnectivity:** Update the api
  * **networkmanagement:** Update the api
  * **recaptchaenterprise:** Update the api
  * **redis:** Update the api
  * **run:** Update the api
  * **searchads360:** Update the api
  * **securitycenter:** Update the api
  * **serviceusage:** Update the api
  * **spanner:** Update the api
  * **vmmigration:** Update the api
  * **youtube:** Update the api
- from version 2.141.0
  * **aiplatform:** Update the api
  * **androidmanagement:** Update the api
  * **assuredworkloads:** Update the api
  * **backupdr:** Update the api
  * **beyondcorp:** Update the api
  * **bigquerydatapolicy:** Update the api
  * **bigquerydatatransfer:** Update the api
  * **bigquery:** Update the api
  * **certificatemanager:** Update the api
  * **cloudbuild:** Update the api
  * **cloudcontrolspartner:** Update the api
  * **clouddeploy:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **domains:** Update the api
  * **firebaseml:** Update the api
  * **firestore:** Update the api
  * **gkehub:** Update the api
  * **networkmanagement:** Update the api
  * **networksecurity:** Update the api
  * **notebooks:** Update the api
  * **realtimebidding:** Update the api
  * **recaptchaenterprise:** Update the api
  * **retail:** Update the api
  * **run:** Update the api
  * **securitycenter:** Update the api
  * **servicecontrol:** Update the api
  * **spanner:** Update the api
  * **storage:** Update the api
  * **vault:** Update the api
  * **walletobjects:** Update the api
  * **workstations:** Update the api
  * **cloudkms:** Update the api
  * **pubsub:** Update the api
  * **secretmanager:** Update the api
- from version 2.140.0
  * **aiplatform:** Update the api
  * **analyticsadmin:** Update the api
  * **cloudchannel:** Update the api
  * **cloudfunctions:** Update the api
  * **compute:** Update the api
  * **containeranalysis:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **firebaseml:** Update the api
  * **healthcare:** Update the api
  * **merchantapi:** Update the api
  * **networkservices:** Update the api
  * **recaptchaenterprise:** Update the api
  * **sqladmin:** Update the api
  * **cloudkms:** Update the api
* Wed Jul 31 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.139.0
  * **appengine:** Update the api
  * **bigquery:** Update the api
  * **bigtableadmin:** Update the api
  * **cloudbuild:** Update the api
  * **contactcenterinsights:** Update the api
  * **contentwarehouse:** Update the api
  * **datamigration:** Update the api
  * **dataplex:** Update the api
  * **dialogflow:** Update the api
  * **discovery:** Update the api
  * **dlp:** Update the api
  * **dns:** Update the api
  * **file:** Update the api
  * **firebaseappdistribution:** Update the api
  * **firebaseml:** Update the api
  * **merchantapi:** Update the api
  * **monitoring:** Update the api
  * **networkmanagement:** Update the api
  * **networksecurity:** Update the api
  * **playintegrity:** Update the api
  * **recaptchaenterprise:** Update the api
  * **walletobjects:** Update the api
  * **workloadmanager:** Update the api
- from version 2.138.0
  * Add support for reading apiVersion in discovery artifacts (#2380)
  * **aiplatform:** Update the api
  * **aiplatform:** Update the api
  * **analyticsadmin:** Update the api
  * **analyticsadmin:** Update the api
  * **androidpublisher:** Update the api
  * **androidpublisher:** Update the api
  * **apim:** Update the api
  * **artifactregistry:** Update the api
  * **artifactregistry:** Update the api
  * **artifactregistry:** Update the api
  * **backupdr:** Update the api
  * **cloudbuild:** Update the api
  * **cloudbuild:** Update the api
  * **cloudcontrolspartner:** Update the api
  * **cloudsearch:** Update the api
  * **composer:** Update the api
  * **compute:** Update the api
  * **compute:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **connectors:** Update the api
  * **connectors:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **dialogflow:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **discoveryengine:** Update the api
  * **discoveryengine:** Update the api
  * **discovery:** Update the api
  * **displayvideo:** Update the api
  * **docs:** Update the api
  * **documentai:** Update the api
  * **essentialcontacts:** Update the api
  * **essentialcontacts:** Update the api
  * **file:** Update the api
  * **file:** Update the api
  * **firebaseappdistribution:** Update the api
  * **firebaseappdistribution:** Update the api
  * **firebaseml:** Update the api
  * **firestore:** Update the api
  * **gkehub:** Update the api
  * **gkehub:** Update the api
  * **healthcare:** Update the api
  * **iam:** Update the api
  * **iam:** Update the api
  * **integrations:** Update the api
  * **integrations:** Update the api
  * **logging:** Update the api
  * **logging:** Update the api
  * **manufacturers:** Update the api
  * **merchantapi:** Update the api
  * **merchantapi:** Update the api
  * **merchantapi:** Update the api
  * **metastore:** Update the api
  * **metastore:** Update the api
  * **migrationcenter:** Update the api
  * **networkservices:** Update the api
  * **networkservices:** Update the api
  * **ondemandscanning:** Update the api
  * **ondemandscanning:** Update the api
  * **playintegrity:** Update the api
  * **playintegrity:** Update the api
  * **recaptchaenterprise:** Update the api
  * **retail:** Update the api
  * **retail:** Update the api
  * **retail:** Update the api
  * **sheets:** Update the api
  * **spanner:** Update the api
  * **spanner:** Update the api
  * **spanner:** Update the api
  * **sqladmin:** Update the api
  * **sqladmin:** Update the api
  * **sts:** Update the api
  * **sts:** Update the api
  * **translate:** Update the api
  * **vmmigration:** Update the api
  * **walletobjects:** Update the api
  * **workflowexecutions:** Update the api
  * **workloadmanager:** Update the api
  * **workloadmanager:** Update the api
  * **workstations:** Update the api
  * **workstations:** Update the api
  * **workstations:** Update the api
  * **dataflow:** Update the api
  * **dlp:** Update the api
  * **dlp:** Update the api
* Mon Jul 15 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.137.0
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **analyticsadmin:** Update the api
  * **assuredworkloads:** Update the api
  * **backupdr:** Update the api
  * **bigquery:** Update the api
  * **bigtableadmin:** Update the api
  * **cloudbuild:** Update the api
  * **clouderrorreporting:** Update the api
  * **contactcenterinsights:** Update the api
  * **containeranalysis:** Update the api
  * **container:** Update the api
  * **dataform:** Update the api
  * **datafusion:** Update the api
  * **dataplex:** Update the api
  * **discoveryengine:** Update the api
  * **dlp:** Update the api
  * **firebaseappcheck:** Update the api
  * **firebaseml:** Update the api
  * **games:** Update the api
  * **integrations:** Update the api
  * **pubsub:** Update the api
  * **run:** Update the api
  * **storage:** Update the api
  * **tagmanager:** Update the api
  * **vmmigration:** Update the api
  * **vmwareengine:** Update the api
  * **workloadmanager:** Update the api
  * **connectors:** Update the api
- Adjust upstream source name in spec file
* Thu Jul  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.136.0
  * **accesscontextmanager:** Update the api
  * **analyticshub:** Update the api
  * **beyondcorp:** Update the api
  * **bigquery:** Update the api
  * **chat:** Update the api
  * **cloudcontrolspartner:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **containeranalysis:** Update the api
  * **dataflow:** Update the api
  * **dialogflow:** Update the api
  * **displayvideo:** Update the api
  * **dlp:** Update the api
  * **file:** Update the api
  * **firebaseappdistribution:** Update the api
  * **gkehub:** Update the api
  * **logging:** Update the api
  * **metastore:** Update the api
  * **migrationcenter:** Update the api
  * **ondemandscanning:** Update the api
  * **policysimulator:** Update the api
  * **pubsub:** Update the api
  * **sqladmin:** Update the api
  * **storage:** Update the api
  * **tasks:** Update the api
  * **vault:** Update the api
  * **workloadmanager:** Update the api
  * **workstations:** Update the api
  * **factchecktools:** Update the api
- from version 2.135.0
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **androidmanagement:** Update the api
  * **androidpublisher:** Update the api
  * **beyondcorp:** Update the api
  * **classroom:** Update the api
  * **containeranalysis:** Update the api
  * **datafusion:** Update the api
  * **dataproc:** Update the api
  * **dlp:** Update the api
  * **firestore:** Update the api
  * **games:** Update the api
  * **healthcare:** Update the api
  * **iap:** Update the api
  * **integrations:** Update the api
  * **jobs:** Update the api
  * **monitoring:** Update the api
  * **networkconnectivity:** Update the api
  * **securitycenter:** Update the api
  * **vmmigration:** Update the api
  * **walletobjects:** Update the api
  * **workloadmanager:** Update the api
  * **bigquerydatatransfer:** Update the api
  * **bigqueryreservation:** Update the api
- from version 2.134.0
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **batch:** Update the api
  * **civicinfo:** Update the api
  * **cloudbuild:** Update the api
  * **cloudidentity:** Update the api
  * **cloudkms:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **dataform:** Update the api
  * **dataplex:** Update the api
  * **dfareporting:** Update the api
  * **discoveryengine:** Update the api
  * **displayvideo:** Update the api
  * **dlp:** Update the api
  * **domains:** Update the api
  * **file:** Update the api
  * **firebaseml:** Update the api
  * **firestore:** Update the api
  * **kmsinventory:** Update the api
  * **metastore:** Update the api
  * **migrationcenter:** Update the api
  * **retail:** Update the api
  * **serviceconsumermanagement:** Update the api
  * **spanner:** Update the api
* Wed Jun 19 2024 Dirk Müller <dmueller@suse.com>
- update to 2.133.0:
  * **accessapproval:** Update the api
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **androidmanagement:** Update the api
  * **bigqueryconnection:** Update the api
  * **bigquery:** Update the api
  * **clouddeploy:** Update the api
  * **connectors:** Update the api
  * **contactcenteraiplatform:** Update the api
  * **dataplex:** Update the api
  * **dataproc:** Update the api
  * **datastream:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **dns:** Update the api
  * **domains:** Update the api
  * **games:** Update the api
  * **memcache:** Update the api
  * **networkconnectivity:** Update the api
  * **notebooks:** Update the api
  * **pubsub:** Update the api
  * **redis:** Update the api
  * **sqladmin:** Update the api
  * **vmmigration:** Update the api
- update to 2.132.0:
  * **aiplatform:** Update the api
  * **analyticsadmin:** Update the api
  * **androidmanagement:** Update the api
  * **backupdr:** Update the api
  * **chromemanagement:** Update the api
  * **cloudbilling:** Update the api
  * **cloudfunctions:** Update the api
  * **cloudsearch:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **datastream:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **documentai:** Update the api
  * **fcmdata:** Update the api
  * **firebaseappcheck:** Update the api
  * **healthcare:** Update the api
  * **iam:** Update the api
  * **integrations:** Update the api
  * **migrationcenter:** Update the api
  * **networkconnectivity:** Update the api
  * **policyanalyzer:** Update the api
  * **resourcesettings:** Update the api
  * **run:** Update the api
  * **servicecontrol:** Update the api
  * **spanner:** Update the api
  * **versionhistory:** Update the api
  * **beyondcorp:** Update the api
  * **composer:** Update the api
  * **compute:** Update the api
  * **contactcenteraiplatform:** Update the api
  * **file:** Update the api
  * **firebaseml:** Update the api
  * **gkebackup:** Update the api
  * **gmail:** Update the api
  * **ids:** Update the api
  * **networkmanagement:** Update the api
  * **networkservices:** Update the api
  * **recaptchaenterprise:** Update the api
  * **redis:** Update the api
  * **sqladmin:** Update the api
  * **storage:** Update the api
  * **tasks:** Update the api
  * **workstations:** Update the api
  * **drive:** Update the api
  * **prod_tt_sasportal:** Update the api
  * **sasportal:** Update the api
  * **secretmanager:** Update the api
* Mon May 27 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.130.0
  * **admin:** Update the api
  * **analyticsadmin:** Update the api
  * **analyticsdata:** Update the api
  * **androidpublisher:** Update the api
  * **artifactregistry:** Update the api
  * **backupdr:** Update the api
  * **chromemanagement:** Update the api
  * **cloudbuild:** Update the api
  * **clouddeploy:** Update the api
  * **cloudkms:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **containeranalysis:** Update the api
  * **containeranalysis:** Update the api
  * **content:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **dlp:** Update the api
  * **fcmdata:** Update the api
  * **firebaseml:** Update the api
  * **firestore:** Update the api
  * **gkehub:** Update the api
  * **healthcare:** Update the api
  * **integrations:** Update the api
  * **integrations:** Update the api
  * **metastore:** Update the api
  * **migrationcenter:** Update the api
  * **networkconnectivity:** Update the api
  * **orgpolicy:** Update the api
  * **osconfig:** Update the api
  * **pagespeedonline:** Update the api
  * **places:** Update the api
  * **run:** Update the api
  * **securitycenter:** Update the api
  * **serviceconsumermanagement:** Update the api
  * **sqladmin:** Update the api
  * **walletobjects:** Update the api
  * **webfonts:** Update the api
  * **workflows:** Update the api
  * **youtube:** Update the api
- from version 2.129.0
  * **admin:** Update the api
  * **aiplatform:** Update the api
  * **apigee:** Update the api
  * **artifactregistry:** Update the api
  * **authorizedbuyersmarketplace:** Update the api
  * **cloudidentity:** Update the api
  * **cloudsearch:** Update the api
  * **compute:** Update the api
  * **contactcenterinsights:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **dataform:** Update the api
  * **firebaseml:** Update the api
  * **firestore:** Update the api
  * **iam:** Update the api
  * **logging:** Update the api
  * **monitoring:** Update the api
  * **networkmanagement:** Update the api
  * **networksecurity:** Update the api
  * **playintegrity:** Update the api
  * **storagetransfer:** Update the api
  * **walletobjects:** Update the api
  * **workloadmanager:** Update the api
- from version 2.128.0
  * **accessapproval:** Update the api
  * **accesscontextmanager:** Update the api
  * **admin:** Update the api
  * **aiplatform:** Update the api
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **alloydb:** Update the api
  * **androidmanagement:** Update the api
  * **artifactregistry:** Update the api
  * **artifactregistry:** Update the api
  * **baremetalsolution:** Update the api
  * **beyondcorp:** Update the api
  * **beyondcorp:** Update the api
  * **bigqueryconnection:** Update the api
  * **bigquery:** Update the api
  * **bigtableadmin:** Update the api
  * **chat:** Update the api
  * **cloudbuild:** Update the api
  * **clouddeploy:** Update the api
  * **cloudkms:** Update the api
  * **cloudsupport:** Update the api
  * **cloudsupport:** Update the api
  * **compute:** Update the api
  * **compute:** Update the api
  * **config:** Update the api
  * **contactcenterinsights:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **contentwarehouse:** Update the api
  * **dataflow:** Update the api
  * **dataform:** Update the api
  * **dataform:** Update the api
  * **datamigration:** Update the api
  * **dataplex:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **dlp:** Update the api
  * **dns:** Update the api
  * **documentai:** Update the api
  * **doubleclickbidmanager:** Update the api
  * **eventarc:** Update the api
  * **firebaseappcheck:** Update the api
  * **firebaseml:** Update the api
  * **firebaseml:** Update the api
  * **games:** Update the api
  * **gkehub:** Update the api
  * **gmail:** Update the api
  * **iap:** Update the api
  * **integrations:** Update the api
  * **logging:** Update the api
  * **migrationcenter:** Update the api
  * **monitoring:** Update the api
  * **networkconnectivity:** Update the api
  * **networkmanagement:** Update the api
  * **ondemandscanning:** Update the api
  * **orgpolicy:** Update the api
  * **privateca:** Update the api
  * **redis:** Update the api
  * **retail:** Update the api
  * **run:** Update the api
  * **serviceconsumermanagement:** Update the api
  * **servicecontrol:** Update the api
  * **servicecontrol:** Update the api
  * **servicemanagement:** Update the api
  * **servicenetworking:** Update the api
  * **serviceusage:** Update the api
  * **sheets:** Update the api
  * **solar:** Update the api
  * **spanner:** Update the api
  * **sts:** Update the api
  * **youtube:** Update the api
  * **secretmanager:** Update the api
- from version 2.127.0
  * **aiplatform:** Update the api
  * **alertcenter:** Update the api
  * **alloydb:** Update the api
  * **analyticshub:** Update the api
  * **androidmanagement:** Update the api
  * **androidpublisher:** Update the api
  * **apigee:** Update the api
  * **authorizedbuyersmarketplace:** Update the api
  * **backupdr:** Update the api
  * **beyondcorp:** Update the api
  * **chat:** Update the api
  * **cloudasset:** Update the api
  * **cloudbuild:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **contactcenteraiplatform:** Update the api
  * **contactcenterinsights:** Update the api
  * **content:** Update the api
  * **customsearch:** Update the api
  * **dataflow:** Update the api
  * **dataplex:** Update the api
  * **datastream:** Update the api
  * **displayvideo:** Update the api
  * **documentai:** Update the api
  * **firebaseml:** Update the api
  * **iam:** Update the api
  * **integrations:** Update the api
  * **metastore:** Update the api
  * **migrationcenter:** Update the api
  * **networkmanagement:** Update the api
  * **redis:** Update the api
  * **retail:** Update the api
  * **run:** Update the api
  * **serviceconsumermanagement:** Update the api
  * **servicecontrol:** Update the api
  * **tpu:** Update the api
  * **youtube:** Update the api
  * **logging:** Update the api
- Disable two more tests that require internet connection
  * test_client_options_universe_configured_with_mtls
  * test_universe_env_var_configured_with_mtls
* Thu Apr 18 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.126.0
  * **advisorynotifications:** Update the api
  * **aiplatform:** Update the api
  * **alertcenter:** Update the api
  * **analyticsadmin:** Update the api
  * **androidmanagement:** Update the api
  * **androidpublisher:** Update the api
  * **cloudsupport:** Update the api
  * **compute:** Update the api
  * **compute:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **content:** Update the api
  * **contentwarehouse:** Update the api
  * **discoveryengine:** Update the api
  * **discoveryengine:** Update the api
  * **dlp:** Update the api
  * **documentai:** Update the api
  * **integrations:** Update the api
  * **integrations:** Update the api
  * **marketingplatformadmin:** Update the api
  * **monitoring:** Update the api
  * **paymentsresellersubscription:** Update the api
  * **searchads360:** Update the api
  * **securitycenter:** Update the api
  * **trafficdirector:** Update the api
  * **verifiedaccess:** Update the api
  * **youtube:** Update the api
  * Added Added syntax highlighting to README (#2384)
  * **dataportability:** Update the api
  * **dataportability:** Update the api
- from version 2.125.0
  * **aiplatform:** Update the api
  * **alertcenter:** Update the api
  * **alloydb:** Update the api
  * **analyticsadmin:** Update the api
  * **apphub:** Update the api
  * **beyondcorp:** Update the api
  * **bigqueryconnection:** Update the api
  * **bigquery:** Update the api
  * **bigtableadmin:** Update the api
  * **chat:** Update the api
  * **compute:** Update the api
  * **content:** Update the api
  * **contentwarehouse:** Update the api
  * **customsearch:** Update the api
  * **dataform:** Update the api
  * **datamigration:** Update the api
  * **dataplex:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **discovery:** Update the api
  * **domains:** Update the api
  * **factchecktools:** Update the api
  * **firestore:** Update the api
  * **gkebackup:** Update the api
  * **gkehub:** Update the api
  * **metastore:** Update the api
  * **migrationcenter:** Update the api
  * **orgpolicy:** Update the api
  * **pubsub:** Update the api
  * **recaptchaenterprise:** Update the api
  * **redis:** Update the api
  * **retail:** Update the api
  * **run:** Update the api
  * **servicecontrol:** Update the api
  * **spanner:** Update the api
  * **sqladmin:** Update the api
  * **workstations:** Update the api
- from version 2.124.0
  * Add support to validate credentials for configured universe (#2362)
  * **adsense:** Update the api
  * **aiplatform:** Update the api
  * Allow users to configure client option `universe_domain` (#2368)
  * Allow users to configure universe environment variable (#2369)
  * **alloydb:** Update the api
  * **androidpublisher:** Update the api
  * **apigee:** Update the api
  * **bigqueryreservation:** Update the api
  * **bigtableadmin:** Update the api
  * **certificatemanager:** Update the api
  * **cloudsupport:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **container:** Update the api
  * **customsearch:** Update the api
  * **datacatalog:** Update the api
  * **dataproc:** Update the api
  * **datastore:** Update the api
  * **firestore:** Update the api
  * **gkehub:** Update the api
  * **iam:** Update the api
  * **identitytoolkit:** Update the api
  * **metastore:** Update the api
  * **redis:** Update the api
  * **secretmanager:** Update the api
  * **sqladmin:** Update the api
  * **testing:** Update the api
  * Validate credentials for universe before request (#2367)
  * **workloadmanager:** Update the api
  * **dataflow:** Update the api
  * **dataportability:** Update the api
  * **deps:** Require google-auth-httplib2 >= 0.2.0 (727c073)
  * **deps:** Require google-auth&gt;=1.32.0 (727c073)
  * **deps:** Require httplib2&gt;=0.19.0  (727c073)
  * **storage:** Update the api
- from version 2.123.0
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **analyticsadmin:** Update the api
  * **analyticshub:** Update the api
  * **bigtableadmin:** Update the api
  * **chat:** Update the api
  * **chromemanagement:** Update the api
  * **cloudbilling:** Update the api
  * **cloudbuild:** Update the api
  * **cloudidentity:** Update the api
  * **compute:** Update the api
  * **content:** Update the api
  * **datacatalog:** Update the api
  * **dataform:** Update the api
  * **datamigration:** Update the api
  * **dataplex:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **documentai:** Update the api
  * **firestore:** Update the api
  * **iam:** Update the api
  * **integrations:** Update the api
  * **logging:** Update the api
  * **networkmanagement:** Update the api
  * **osconfig:** Update the api
  * **redis:** Update the api
  * **run:** Update the api
  * **secretmanager:** Update the api
  * **spanner:** Update the api
  * **storagetransfer:** Update the api
  * **storage:** Update the api
  * **sts:** Update the api
  * **tasks:** Update the api
  * **dataproc:** Update the api
  * **people:** Update the api
- from version 2.122.0
  * **admin:** Update the api
  * **adsense:** Update the api
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **artifactregistry:** Update the api
  * **beyondcorp:** Update the api
  * **bigquerydatatransfer:** Update the api
  * **bigquery:** Update the api
  * **bigtableadmin:** Update the api
  * **cloudbilling:** Update the api
  * **cloudbuild:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **containeranalysis:** Update the api
  * **content:** Update the api
  * **dataform:** Update the api
  * **dataplex:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **file:** Update the api
  * **gkehub:** Update the api
  * **language:** Update the api
  * **looker:** Update the api
  * **networksecurity:** Update the api
  * **places:** Update the api
  * **playdeveloperreporting:** Update the api
  * **run:** Update the api
  * **secretmanager:** Update the api
  * **serviceusage:** Update the api
  * **slides:** Update the api
  * **sqladmin:** Update the api
  * **storage:** Update the api
  * **vault:** Update the api
  * **workloadmanager:** Update the api
  * **workstations:** Update the api
  * **youtube:** Update the api
  * **dataflow:** Update the api
  * **logging:** Update the api
  * **workspaceevents:** Update the api
- from version 2.121.0
  * **alloydb:** Update the api
  * **apigee:** Update the api
  * **appengine:** Update the api
  * **apphub:** Update the api
  * **authorizedbuyersmarketplace:** Update the api
  * **chromemanagement:** Update the api
  * **cloudbuild:** Update the api
  * **clouddeploy:** Update the api
  * **cloudresourcemanager:** Update the api
  * **composer:** Update the api
  * **container:** Update the api
  * **discoveryengine:** Update the api
  * **dlp:** Update the api
  * **dns:** Update the api
  * **documentai:** Update the api
  * **firestore:** Update the api
  * **gkehub:** Update the api
  * **healthcare:** Update the api
  * **logging:** Update the api
  * **metastore:** Update the api
  * **networkmanagement:** Update the api
  * **policysimulator:** Update the api
  * **redis:** Update the api
  * **retail:** Update the api
  * **securitycenter:** Update the api
  * **servicecontrol:** Update the api
  * **storagetransfer:** Update the api
  * **vmmigration:** Update the api
  * **youtube:** Update the api
  * **dataportability:** Update the api
  * **pubsub:** Update the api
- from version 2.12.0
  * **admin:** Update the api
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **analyticshub:** Update the api
  * **apigee:** Update the api
  * **appengine:** Update the api
  * **bigtableadmin:** Update the api
  * **binaryauthorization:** Update the api
  * **cloudprofiler:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **containeranalysis:** Update the api
  * **container:** Update the api
  * **datacatalog:** Update the api
  * **dataflow:** Update the api
  * **dataplex:** Update the api
  * **datastore:** Update the api
  * **dialogflow:** Update the api
  * **displayvideo:** Update the api
  * **firestore:** Update the api
  * **language:** Update the api
  * **logging:** Update the api
  * **looker:** Update the api
  * **metastore:** Update the api
  * **networkconnectivity:** Update the api
  * **paymentsresellersubscription:** Update the api
  * **places:** Update the api
  * **policysimulator:** Update the api
  * **privateca:** Update the api
  * **serviceusage:** Update the api
  * **storagetransfer:** Update the api
  * **youtube:** Update the api
  * **bigqueryreservation:** Update the api
  * **cloudkms:** Update the api
- from version 2.119.0
  * **aiplatform:** Update the api
  * **androidmanagement:** Update the api
  * **androidpublisher:** Update the api
  * **appengine:** Update the api
  * **apphub:** Update the api
  * **binaryauthorization:** Update the api
  * **blockchainnodeengine:** Update the api
  * **books:** Update the api
  * **certificatemanager:** Update the api
  * **connectors:** Update the api
  * **container:** Update the api
  * **datacatalog:** Update the api
  * **dataproc:** Update the api
  * **datastore:** Update the api
  * **datastream:** Update the api
  * **firestore:** Update the api
  * **gkehub:** Update the api
  * **language:** Update the api
  * **localservices:** Update the api
  * **networkservices:** Update the api
  * **securitycenter:** Update the api
  * **storage:** Update the api
  * **testing:** Update the api
  * **transcoder:** Update the api
  * **walletobjects:** Update the api
  * **workspaceevents:** Update the api
  * **youtube:** Update the api
- from version 2.118.0
  * **aiplatform:** Update the api
  * **androidmanagement:** Update the api
  * **androidpublisher:** Update the api
  * **bigquery:** Update the api
  * **cloudbuild:** Update the api
  * **cloudfunctions:** Update the api
  * **composer:** Update the api
  * **compute:** Update the api
  * **contactcenterinsights:** Update the api
  * **dataform:** Update the api
  * **dataplex:** Update the api
  * **datastore:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **firestore:** Update the api
  * **healthcare:** Update the api
  * **networkmanagement:** Update the api
  * **recaptchaenterprise:** Update the api
  * **retail:** Update the api
  * **searchads360:** Update the api
  * **spanner:** Update the api
  * **sqladmin:** Update the api
  * **storage:** Update the api
  * **testing:** Update the api
  * **tpu:** Update the api
  * **trafficdirector:** Update the api
  * **workloadmanager:** Update the api
  * **run:** Update the api
  * **youtube:** Update the api
- from version 2.117.0
  * **alertcenter:** Update the api
  * **androidmanagement:** Update the api
  * **apphub:** Update the api
  * **bigquerydatatransfer:** Update the api
  * **blockchainnodeengine:** Update the api
  * **cloudbuild:** Update the api
  * **cloudidentity:** Update the api
  * **cloudsupport:** Update the api
  * **composer:** Update the api
  * **compute:** Update the api
  * **container:** Update the api
  * **dfareporting:** Update the api
  * **discoveryengine:** Update the api
  * **gkeonprem:** Update the api
  * **integrations:** Update the api
  * **networkmanagement:** Update the api
  * **networksecurity:** Update the api
  * **paymentsresellersubscription:** Update the api
  * **pubsub:** Update the api
  * **run:** Update the api
  * **sasportal:** Update the api
  * **secretmanager:** Update the api
  * **securitycenter:** Update the api
  * **spanner:** Update the api
  * **storagetransfer:** Update the api
  * **storage:** Update the api
  * **tpu:** Update the api
  * **transcoder:** Update the api
  * **walletobjects:** Update the api
  * **workstations:** Update the api
  * **admin:** Update the api
- Update BuildRequires and Requires from setup.py
* Sat Feb  3 2024 Dirk Müller <dmueller@suse.com>
- update to 2.116.0:
  * **aiplatform:** Update the api
  * **androidmanagement:** Update the api
  * **androidpublisher:** Update the api
  * **artifactregistry:** Update the api
  * **bigqueryconnection:** Update the api
  * **bigquery:** Update the api
  * **bigtableadmin:** Update the api
  * **blockchainnodeengine:** Update the api
  * **cloudasset:** Update the api
  * **clouddeploy:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **dataflow:** Update the api
  * **dataform:** Update the api
  * **datastore:** Update the api
  * **displayvideo:** Update the api
  * **drive:** Update the api
  * **firebaseappcheck:** Update the api
  * **firestore:** Update the api
  * **migrationcenter:** Update the api
  * **monitoring:** Update the api
  * **networkmanagement:** Update the api
  * **recommender:** Update the api
  * **retail:** Update the api
  * **spanner:** Update the api
  * **sqladmin:** Update the api
  * **workflowexecutions:** Update the api
  * **workloadmanager:** Update the api
  * **youtube:** Update the api
* Wed Jan 24 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.115.0
  * **aiplatform:** Update the api
  * **analyticsadmin:** Update the api
  * **apigee:** Update the api
  * **apphub:** Update the api
  * **cloudsupport:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **dataflow:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **displayvideo:** Update the api
  * **documentai:** Update the api
  * **gkehub:** Update the api
  * **logging:** Update the api
  * **monitoring:** Update the api
  * **notebooks:** Update the api
  * **policysimulator:** Update the api
  * **prod_tt_sasportal:** Update the api
  * **recaptchaenterprise:** Update the api
  * **retail:** Update the api
  * **securitycenter:** Update the api
  * **tpu:** Update the api
  * **vmwareengine:** Update the api
* Sat Jan 20 2024 Dirk Müller <dmueller@suse.com>
- update to 2.114.0:
  * **aiplatform:** Update the api
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **androidpublisher:** Update the api
  * **batch:** Update the api
  * **bigquery:** Update the api
  * **blockchainnodeengine:** Update the api
  * **chat:** Update the api
  * **chromepolicy:** Update the api
  * **clouddeploy:** Update the api
  * **cloudfunctions:** Update the api
  * **composer:** Update the api
  * **compute:** Update the api
  * **compute:** Update the api
  * **contactcenteraiplatform:** Update the api
  * **dataflow:** Update the api
  * **datastream:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **dlp:** Update the api
  * **integrations:** Update the api
  * **logging:** Update the api
  * **migrationcenter:** Update the api
  * **monitoring:** Update the api
  * **prod_tt_sasportal:** Update the api
  * **recommender:** Update the api
  * **retail:** Update the api
  * **sasportal:** Update the api
  * **securitycenter:** Update the api
  * **speech:** Update the api
  * **storage:** Update the api
  * **texttospeech:** Update the api
  * **toolresults:** Update the api
  * **vmwareengine:** Update the api
  * **walletobjects:** Update the api
  * **workloadmanager:** Update the api
  * **workstations:** Update the api
  * Removed indent from discovery cache json files (#2099)
    (0a28454), closes #1967
* Sat Jan 13 2024 Dirk Müller <dmueller@suse.com>
- update to 2.113.0:
  * **androidmanagement:** Update the api
  * **batch:** Update the api
  * **bigtableadmin:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **contactcenterinsights:** Update the api
  * **content:** Update the api
  * **customsearch:** Update the api
  * **displayvideo:** Update the api
  * **firestore:** Update the api
  * **script:** Update the api
* Fri Jan  5 2024 Dirk Müller <dmueller@suse.com>
- update to 2.112.0:
  * **accesscontextmanager:** Update the api
  * **admin:** Update the api
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **apigee:** Update the api
  * **artifactregistry:** Update the api
  * **backupdr:** Update the api
  * **chat:** Update the api
  * **checks:** Update the api
  * **chromepolicy:** Update the api
  * **chromeuxreport:** Update the api
  * **cloudbuild:** Update the api
  * **cloudchannel:** Update the api
  * **cloudfunctions:** Update the api
  * **cloudprofiler:** Update the api
  * **cloudsupport:** Update the api
  * **connectors:** Update the api
  * **container:** Update the api
  * **dataflow:** Update the api
  * **dataform:** Update the api
  * **dataproc:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **dlp:** Update the api
  * **drivelabels:** Update the api
  * **firebaseappdistribution:** Update the api
  * **gkehub:** Update the api
  * **gmail:** Update the api
  * **healthcare:** Update the api
  * **integrations:** Update the api
  * **migrationcenter:** Update the api
  * **monitoring:** Update the api
  * **networkmanagement:** Update the api
  * **networkservices:** Update the api
  * **oslogin:** Update the api
  * **playintegrity:** Update the api
  * **prod_tt_sasportal:** Update the api
  * **retail:** Update the api
  * **run:** Update the api
  * **sasportal:** Update the api
  * **securitycenter:** Update the api
  * **serviceconsumermanagement:** Update the api
  * **vault:** Update the api
  * **workloadmanager:** Update the api
  * **workstations:** Update the api
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 2.111.0:
  * Add support for Python 3.12 (#2288)
  * **aiplatform:** Update the api
  * **alloydb:** Update the api
  * **androidpublisher:** Update the api
  * **baremetalsolution:** Update the api
  * **batch:** Update the api
  * **bigquery:** Update the api
  * **cloudbilling:** Update the api
  * **clouddeploy:** Update the api
  * **connectors:** Update the api
  * **container:** Update the api
  * **datacatalog:** Update the api
  * **dataflow:** Update the api
  * **dns:** Update the api
  * **gkehub:** Update the api
  * **gkeonprem:** Update the api
  * **metastore:** Update the api
  * **monitoring:** Update the api
  * **networkmanagement:** Update the api
  * **networksecurity:** Update the api
  * **networkservices:** Update the api
  * **playdeveloperreporting:** Update the api
  * **pubsub:** Update the api
  * **script:** Update the api
  * **securitycenter:** Update the api
  * **vpcaccess:** Update the api
  * Replace deprecated utcnow, utcfromtimestamp (#2286)
* Wed Nov 22 2023 Antonio Larrosa <alarrosa@suse.com>
- Remove pandas from the BuildRequires. It's not really needed.
* Thu Oct 12 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.103.0
  * **aiplatform:** Update the api
  * **analyticsadmin:** Update the api
  * **analyticshub:** Update the api
  * **androidmanagement:** Update the api
  * **batch:** Update the api
  * **beyondcorp:** Update the api
  * **bigqueryreservation:** Update the api
  * **binaryauthorization:** Update the api
  * **chromepolicy:** Update the api
  * **cloudtasks:** Update the api
  * **composer:** Update the api
  * **compute:** Update the api
  * **container:** Update the api
  * **contentwarehouse:** Update the api
  * **dataflow:** Update the api
  * **datalabeling:** Update the api
  * **dataproc:** Update the api
  * **discoveryengine:** Update the api
  * **dlp:** Update the api
  * **docs:** Update the api
  * **eventarc:** Update the api
  * **firestore:** Update the api
  * **gkehub:** Update the api
  * **gmail:** Update the api
  * **healthcare:** Update the api
  * **iap:** Update the api
  * **integrations:** Update the api
  * **metastore:** Update the api
  * **ondemandscanning:** Update the api
  * **oslogin:** Update the api
  * **recaptchaenterprise:** Update the api
  * **recommender:** Update the api
  * **run:** Update the api
  * **sasportal:** Update the api
  * **securitycenter:** Update the api
  * **youtube:** Update the api
  * **artifactregistry:** Update the api
- from version 2.102.0
  * **aiplatform:** Update the api
  * **analyticsadmin:** Update the api
  * **androidmanagement:** Update the api
  * **apigeeregistry:** Update the api
  * **apigee:** Update the api
  * **baremetalsolution:** Update the api
  * **blockchainnodeengine:** Update the api
  * **chat:** Update the api
  * **chromepolicy:** Update the api
  * **cloudasset:** Update the api
  * **cloudbuild:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **contactcenterinsights:** Update the api
  * **containeranalysis:** Update the api
  * **container:** Update the api
  * **contentwarehouse:** Update the api
  * **dataplex:** Update the api
  * **dataproc:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **documentai:** Update the api
  * **gkebackup:** Update the api
  * **gkeonprem:** Update the api
  * **gmail:** Update the api
  * **integrations:** Update the api
  * **migrationcenter:** Update the api
  * **monitoring:** Update the api
  * **networkservices:** Update the api
  * **places:** Update the api
  * **redis:** Update the api
  * **run:** Update the api
  * **securitycenter:** Update the api
  * **storage:** Update the api
  * **tagmanager:** Update the api
  * **androidpublisher:** Update the api
  * **appengine:** Update the api
  * **healthcare:** Update the api
  * **translate:** Update the api
- from version 2.101.0
  * **accessapproval:** Update the api
  * **aiplatform:** Update the api
  * **analyticsadmin:** Update the api
  * **batch:** Update the api
  * **chat:** Update the api
  * **clouddeploy:** Update the api
  * **composer:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **containeranalysis:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **contentwarehouse:** Update the api
  * **dataform:** Update the api
  * **dataproc:** Update the api
  * **discoveryengine:** Update the api
  * **documentai:** Update the api
  * **eventarc:** Update the api
  * **firebase:** Update the api
  * **gkehub:** Update the api
  * **gmail:** Update the api
  * **healthcare:** Update the api
  * **iam:** Update the api
  * **logging:** Update the api
  * **networksecurity:** Update the api
  * **paymentsresellersubscription:** Update the api
  * **policysimulator:** Update the api
  * **prod_tt_sasportal:** Update the api
  * **recaptchaenterprise:** Update the api
  * **run:** Update the api
  * **vision:** Update the api
  * **vmmigration:** Update the api
- from version 2.100.0
  * **accesscontextmanager:** Update the api
  * **advisorynotifications:** Update the api
  * **aiplatform:** Update the api
  * **androidmanagement:** Update the api
  * **appengine:** Update the api
  * **artifactregistry:** Update the api
  * **assuredworkloads:** Update the api
  * **beyondcorp:** Update the api
  * **blockchainnodeengine:** Update the api
  * **checks:** Update the api
  * **chromemanagement:** Update the api
  * **cloudasset:** Update the api
  * **cloudfunctions:** Update the api
  * **cloudtasks:** Update the api
  * **composer:** Update the api
  * **connectors:** Update the api
  * **contactcenteraiplatform:** Update the api
  * **datamigration:** Update the api
  * **gkeonprem:** Update the api
  * **gmail:** Update the api
  * **integrations:** Update the api
  * **monitoring:** Update the api
  * **mybusinessverifications:** Update the api
  * **networkconnectivity:** Update the api
  * **networkmanagement:** Update the api
  * **notebooks:** Update the api
  * **paymentsresellersubscription:** Update the api
  * **places:** Update the api
  * **run:** Update the api
  * **spanner:** Update the api
  * **storage:** Update the api
  * **transcoder:** Update the api
  * **vision:** Update the api
  * **smartdevicemanagement:** Update the api
- from version 2.99.0
  * **artifactregistry:** Update the api
  * **assuredworkloads:** Update the api
  * **beyondcorp:** Update the api
  * **checks:** Update the api
  * **chromemanagement:** Update the api
  * **cloudasset:** Update the api
  * **cloudbuild:** Update the api
  * **cloudchannel:** Update the api
  * **clouddeploy:** Update the api
  * **compute:** Update the api
  * **contentwarehouse:** Update the api
  * **dataflow:** Update the api
  * **datalineage:** Update the api
  * **dataproc:** Update the api
  * **datastream:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **dlp:** Update the api
  * **firebasehosting:** Update the api
  * **firebase:** Update the api
  * **firestore:** Update the api
  * **games:** Update the api
  * **gkehub:** Update the api
  * **gmailpostmastertools:** Update the api
  * **iap:** Update the api
  * **jobs:** Update the api
  * **memcache:** Update the api
  * **metastore:** Update the api
  * **migrationcenter:** Update the api
  * **networkconnectivity:** Update the api
  * **osconfig:** Update the api
  * **oslogin:** Update the api
  * **places:** Update the api
  * **playintegrity:** Update the api
  * **redis:** Update the api
  * **speech:** Update the api
  * **storage:** Update the api
  * **vmmigration:** Update the api
  * **workflowexecutions:** Update the api
  * **workloadmanager:** Update the api
  * **workstations:** Update the api
- from version 2.98.0
  * **admin:** Update the api
  * **admob:** Update the api
  * **admob:** Update the api
  * **aiplatform:** Update the api
  * **alertcenter:** Update the api
  * **analyticsadmin:** Update the api
  * **androiddeviceprovisioning:** Update the api
  * **androidpublisher:** Update the api
  * **apigee:** Update the api
  * **assuredworkloads:** Update the api
  * **baremetalsolution:** Update the api
  * **baremetalsolution:** Update the api
  * **bigquery:** Update the api
  * **billingbudgets:** Update the api
  * **checks:** Update the api
  * **checks:** Update the api
  * **chromemanagement:** Update the api
  * **chromemanagement:** Update the api
  * **cloudbilling:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **contactcenterinsights:** Update the api
  * **containeranalysis:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **content:** Update the api
  * **datacatalog:** Update the api
  * **datalineage:** Update the api
  * **dataplex:** Update the api
  * **dataproc:** Update the api
  * **deploymentmanager:** Update the api
  * **deploymentmanager:** Update the api
  * **dialogflow:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **discoveryengine:** Update the api
  * **displayvideo:** Update the api
  * **documentai:** Update the api
  * **firebaseappcheck:** Update the api
  * **firebasehosting:** Update the api
  * **firebasestorage:** Update the api
  * **gkehub:** Update the api
  * **gkeonprem:** Update the api
  * **manufacturers:** Update the api
  * **monitoring:** Update the api
  * **networkconnectivity:** Update the api
  * **networkservices:** Update the api
  * **paymentsresellersubscription:** Update the api
  * **places:** Update the api
  * **policysimulator:** Update the api
  * **privateca:** Update the api
  * **prod_tt_sasportal:** Update the api
  * **pubsub:** Update the api
  * **retail:** Update the api
  * **sasportal:** Update the api
  * **searchads360:** Update the api
  * **securitycenter:** Update the api
  * **serviceconsumermanagement:** Update the api
  * **serviceusage:** Update the api
  * **sqladmin:** Update the api
  * **storagetransfer:** Update the api
  * **testing:** Update the api
  * **testing:** Update the api
  * **tpu:** Update the api
  * **verifiedaccess:** Update the api
  * **vmmigration:** Update the api
  * **vmmigration:** Update the api
  * **youtube:** Update the api
  * **youtube:** Update the api
* Wed Aug 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.97.0
  * **adexperiencereport:** Update the api
  * **aiplatform:** Update the api
  * **analyticsadmin:** Update the api
  * **androidmanagement:** Update the api
  * **androidpublisher:** Update the api
  * **appengine:** Update the api
  * **artifactregistry:** Update the api
  * **assuredworkloads:** Update the api
  * **baremetalsolution:** Update the api
  * **beyondcorp:** Update the api
  * **bigquery:** Update the api
  * **binaryauthorization:** Update the api
  * **cloudbuild:** Update the api
  * **composer:** Update the api
  * **connectors:** Update the api
  * **container:** Update the api
  * **contentwarehouse:** Update the api
  * **dataform:** Update the api
  * **dataproc:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **documentai:** Update the api
  * **gkehub:** Update the api
  * **healthcare:** Update the api
  * **identitytoolkit:** Update the api
  * **migrationcenter:** Update the api
  * **monitoring:** Update the api
  * **networkmanagement:** Update the api
  * **paymentsresellersubscription:** Update the api
  * **redis:** Update the api
  * **run:** Update the api
  * **tagmanager:** Update the api
  * **vmmigration:** Update the api
- from version 2.96.0
  * **admin:** Update the api
  * **analyticsadmin:** Update the api
  * **analyticshub:** Update the api
  * **androidmanagement:** Update the api
  * **artifactregistry:** Update the api
  * **assuredworkloads:** Update the api
  * **beyondcorp:** Update the api
  * **bigquerydatatransfer:** Update the api
  * **chat:** Update the api
  * **checks:** Update the api
  * **cloudbuild:** Update the api
  * **clouddeploy:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **contactcenteraiplatform:** Update the api
  * **containeranalysis:** Update the api
  * **container:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **content:** Update the api
  * **contentwarehouse:** Update the api
  * **dataflow:** Update the api
  * **dataform:** Update the api
  * **datamigration:** Update the api
  * **dataplex:** Update the api
  * **dataproc:** Update the api
  * **datastore:** Update the api
  * **datastream:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **displayvideo:** Update the api
  * **documentai:** Update the api
  * **drivelabels:** Update the api
  * **firebase:** Update the api
  * **firestore:** Update the api
  * **gkebackup:** Update the api
  * **gkehub:** Update the api
  * **gkehub:** Update the api
  * **gkeonprem:** Update the api
  * **healthcare:** Update the api
  * **integrations:** Update the api
  * **migrationcenter:** Update the api
  * **monitoring:** Update the api
  * **networkconnectivity:** Update the api
  * **networkconnectivity:** Update the api
  * **notebooks:** Update the api
  * **osconfig:** Update the api
  * **oslogin:** Update the api
  * **places:** Update the api
  * **policysimulator:** Update the api
  * **retail:** Update the api
  * **securitycenter:** Update the api
  * **servicecontrol:** Update the api
  * **servicemanagement:** Update the api
  * **servicenetworking:** Update the api
  * **servicenetworking:** Update the api
  * **serviceusage:** Update the api
  * **smartdevicemanagement:** Update the api
  * **toolresults:** Update the api
  * **tpu:** Update the api
  * **verifiedaccess:** Update the api
  * **youtube:** Update the api
  * **places:** Update the api
- from version 2.95.0
  * **apigee:** Update the api
  * **bigquery:** Update the api
  * **bigtableadmin:** Update the api
  * **checks:** Update the api
  * **cloudbuild:** Update the api
  * **clouddeploy:** Update the api
  * **cloudfunctions:** Update the api
  * **compute:** Update the api
  * **containeranalysis:** Update the api
  * **datacatalog:** Update the api
  * **dataplex:** Update the api
  * **datastream:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **documentai:** Update the api
  * **drive:** Update the api
  * **firebaseappcheck:** Update the api
  * **firestore:** Update the api
  * **gkeonprem:** Update the api
  * **healthcare:** Update the api
  * **monitoring:** Update the api
  * **networksecurity:** Update the api
  * **ondemandscanning:** Update the api
  * **retail:** Update the api
  * **securitycenter:** Update the api
  * **serviceconsumermanagement:** Update the api
  * **servicedirectory:** Update the api
  * **servicenetworking:** Update the api
  * **serviceusage:** Update the api
  * **sheets:** Update the api
  * **sqladmin:** Update the api
  * **tpu:** Update the api
  * **trafficdirector:** Update the api
  * **translate:** Update the api
  * **vault:** Update the api
  * **verifiedaccess:** Update the api
  * **videointelligence:** Update the api
  * **vmmigration:** Update the api
  * **workloadmanager:** Update the api
- from version 2.94.0
  * **analyticsdata:** Update the api
  * **androidenterprise:** Update the api
  * **androidpublisher:** Update the api
  * **appengine:** Update the api
  * **artifactregistry:** Update the api
  * **assuredworkloads:** Update the api
  * **baremetalsolution:** Update the api
  * **batch:** Update the api
  * **bigquery:** Update the api
  * **chat:** Update the api
  * **checks:** Update the api
  * **classroom:** Update the api
  * **cloudasset:** Update the api
  * **cloudbilling:** Update the api
  * **clouddebugger:** Update the api
  * **compute:** Update the api
  * **containeranalysis:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **contentwarehouse:** Update the api
  * **datacatalog:** Update the api
  * **dataform:** Update the api
  * **datamigration:** Update the api
  * **discovery:** Update the api
  * **documentai:** Update the api
  * **doubleclickbidmanager:** Update the api
  * **drive:** Update the api
  * **firestore:** Update the api
  * **gkehub:** Update the api
  * **gkeonprem:** Update the api
  * **homegraph:** Update the api
  * **iam:** Update the api
  * **identitytoolkit:** Update the api
  * **integrations:** Update the api
  * **lifesciences:** Update the api
  * **logging:** Update the api
  * **memcache:** Update the api
  * **networkmanagement:** Update the api
  * **networksecurity:** Update the api
  * **notebooks:** Update the api
  * **ondemandscanning:** Update the api
  * **pubsublite:** Update the api
  * **pubsub:** Update the api
  * **sasportal:** Update the api
  * **securitycenter:** Update the api
  * **servicecontrol:** Update the api
  * **servicemanagement:** Update the api
  * **serviceusage:** Update the api
  * **slides:** Update the api
  * **speech:** Update the api
  * **sqladmin:** Update the api
  * **tpu:** Update the api
  * **verifiedaccess:** Update the api
  * **vision:** Update the api
  * **youtube:** Update the api
  * **smartdevicemanagement:** Update the api
* Tue Jul 18 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.93.0
  * **adexchangebuyer2:** Update the api
  * **analyticshub:** Update the api
  * **androidmanagement:** Update the api
  * **apigee:** Update the api
  * **bigquerydatatransfer:** Update the api
  * **chat:** Update the api
  * **cloudchannel:** Update the api
  * **cloudidentity:** Update the api
  * **cloudscheduler:** Update the api
  * **cloudsearch:** Update the api
  * **cloudsupport:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **contactcenterinsights:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **dataflow:** Update the api
  * **datamigration:** Update the api
  * **dataplex:** Update the api
  * **datastream:** Update the api
  * **dialogflow:** Update the api
  * **dlp:** Update the api
  * **dns:** Update the api
  * **driveactivity:** Update the api
  * **gkeonprem:** Update the api
  * **gmail:** Update the api
  * **healthcare:** Update the api
  * **identitytoolkit:** Update the api
  * **jobs:** Update the api
  * **kmsinventory:** Update the api
  * **managedidentities:** Update the api
  * **migrationcenter:** Update the api
  * **monitoring:** Update the api
  * **networkmanagement:** Update the api
  * **notebooks:** Update the api
  * **orgpolicy:** Update the api
  * **pagespeedonline:** Update the api
  * **prod_tt_sasportal:** Update the api
  * **realtimebidding:** Update the api
  * **retail:** Update the api
  * **securitycenter:** Update the api
  * **serviceconsumermanagement:** Update the api
  * **serviceusage:** Update the api
  * **tagmanager:** Update the api
  * **testing:** Update the api
  * **websecurityscanner:** Update the api
  * **workloadmanager:** Update the api
  * **youtube:** Update the api
- from version 2.92.0
  * **analyticshub:** Update the api
  * **androidenterprise:** Update the api
  * **androidmanagement:** Update the api
  * **androidpublisher:** Update the api
  * **apigateway:** Update the api
  * **apigee:** Update the api
  * **artifactregistry:** Update the api
  * **assuredworkloads:** Update the api
  * **baremetalsolution:** Update the api
  * **batch:** Update the api
  * **bigquery:** Update the api
  * **bigtableadmin:** Update the api
  * **civicinfo:** Update the api
  * **cloudfunctions:** Update the api
  * **cloudkms:** Update the api
  * **cloudsupport:** Update the api
  * **compute:** Update the api
  * **contactcenterinsights:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **contentwarehouse:** Update the api
  * **dataform:** Update the api
  * **datafusion:** Update the api
  * **dataplex:** Update the api
  * **dataproc:** Update the api
  * **displayvideo:** Update the api
  * **eventarc:** Update the api
  * **fcm:** Update the api
  * **file:** Update the api
  * **firebaseappcheck:** Update the api
  * **firebaseappdistribution:** Update the api
  * **firebasedynamiclinks:** Update the api
  * **firebase:** Update the api
  * **firestore:** Update the api
  * **fitness:** Update the api
  * **gkehub:** Update the api
  * **gmailpostmastertools:** Update the api
  * **iam:** Update the api
  * **memcache:** Update the api
  * **metastore:** Update the api
  * **mybusinesslodging:** Update the api
  * **networkconnectivity:** Update the api
  * **osconfig:** Update the api
  * **recaptchaenterprise:** Update the api
  * **run:** Update the api
  * **sasportal:** Update the api
  * **searchads360:** Update the api
  * **searchconsole:** Update the api
  * **servicenetworking:** Update the api
  * **sqladmin:** Update the api
  * **streetviewpublish:** Update the api
  * **toolresults:** Update the api
  * **transcoder:** Update the api
  * **vmmigration:** Update the api
  * **workloadmanager:** Update the api
  * **youtubeAnalytics:** Update the api
  * **youtubereporting:** Update the api
- from version 2.91.0
  * **analyticsadmin:** Update the api
  * **artifactregistry:** Update the api
  * **beyondcorp:** Update the api
  * **chat:** Update the api
  * **cloudfunctions:** Update the api
  * **cloudresourcemanager:** Update the api
  * **compute:** Update the api
  * **contactcenteraiplatform:** Update the api
  * **datamigration:** Update the api
  * **dataplex:** Update the api
  * **dfareporting:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **dlp:** Update the api
  * **documentai:** Update the api
  * **gkehub:** Update the api
  * **gkeonprem:** Update the api
  * **migrationcenter:** Update the api
  * **networkconnectivity:** Update the api
  * **networkservices:** Update the api
  * **notebooks:** Update the api
  * **people:** Update the api
  * **privateca:** Update the api
  * **prod_tt_sasportal:** Update the api
  * **redis:** Update the api
  * **securitycenter:** Update the api
  * **servicedirectory:** Update the api
  * **tpu:** Update the api
  * **workflows:** Update the api
  * **workstations:** Update the api
- from version 2.90.0
  * **androidpublisher:** Update the api
  * **baremetalsolution:** Update the api
  * **batch:** Update the api
  * **beyondcorp:** Update the api
  * **calendar:** Update the api
  * **chat:** Update the api
  * **civicinfo:** Update the api
  * **cloudasset:** Update the api
  * **cloudbilling:** Update the api
  * **cloudchannel:** Update the api
  * **clouddebugger:** Update the api
  * **clouddeploy:** Update the api
  * **cloudfunctions:** Update the api
  * **cloudidentity:** Update the api
  * **cloudsearch:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **contactcenteraiplatform:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **contentwarehouse:** Update the api
  * **dataplex:** Update the api
  * **datastream:** Update the api
  * **dialogflow:** Update the api
  * **displayvideo:** Update the api
  * **eventarc:** Update the api
  * **firebaseappcheck:** Update the api
  * **gkebackup:** Update the api
  * **gkehub:** Update the api
  * **gkeonprem:** Update the api
  * **gmail:** Update the api
  * **identitytoolkit:** Update the api
  * **integrations:** Update the api
  * **logging:** Update the api
  * **migrationcenter:** Update the api
  * **networkmanagement:** Update the api
  * **prod_tt_sasportal:** Update the api
  * **pubsub:** Update the api
  * **recommender:** Update the api
  * **reseller:** Update the api
  * **retail:** Update the api
  * **run:** Update the api
  * **sasportal:** Update the api
  * **serviceusage:** Update the api
  * **spanner:** Update the api
  * **sqladmin:** Update the api
  * **tagmanager:** Update the api
  * **transcoder:** Update the api
  * **workflowexecutions:** Update the api
  * **workloadmanager:** Update the api
* Sun Jul  2 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Jun 20 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.89.0
  * **androidmanagement:** Update the api
  * **apigee:** Update the api
  * **appengine:** Update the api
  * **billingbudgets:** Update the api
  * **cloudidentity:** Update the api
  * **cloudsearch:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **container:** Update the api
  * **contentwarehouse:** Update the api
  * **datacatalog:** Update the api
  * **dataplex:** Update the api
  * **dialogflow:** Update the api
  * **documentai:** Update the api
  * **firebaseappcheck:** Update the api
  * **firestore:** Update the api
  * **healthcare:** Update the api
  * **iam:** Update the api
  * **iap:** Update the api
  * **integrations:** Update the api
  * **language:** Update the api
  * **manufacturers:** Update the api
  * **metastore:** Update the api
  * **mybusinessbusinessinformation:** Update the api
  * **networkconnectivity:** Update the api
  * **paymentsresellersubscription:** Update the api
  * **securitycenter:** Update the api
  * **servicemanagement:** Update the api
  * **sqladmin:** Update the api
  * **streetviewpublish:** Update the api
  * **testing:** Update the api
  * **verifiedaccess:** Update the api
  * Remove faulty version matcher in setup.py (#2152), closes (#2151)
- from version 2.88.0
  * **baremetalsolution:** Update the api
  * **beyondcorp:** Update the api
  * **beyondcorp:** Update the api
  * **bigqueryreservation:** Update the api
  * **cloudidentity:** Update the api
  * **container:** Update the api
  * **dataflow:** Update the api
  * **datastream:** Update the api
  * **discoveryengine:** Update the api
  * **dlp:** Update the api
  * **drive:** Update the api
  * **firebaseappcheck:** Update the api
  * **gkeonprem:** Update the api
  * **integrations:** Update the api
  * **logging:** Update the api
  * **ondemandscanning:** Update the api
- from version 2.87.0
  * **accessapproval:** Update the api
  * **alertcenter:** Update the api
  * **analyticsadmin:** Update the api
  * **analyticshub:** Update the api
  * **androiddeviceprovisioning:** Update the api
  * **androidmanagement:** Update the api
  * **androidpublisher:** Update the api
  * **apigee:** Update the api
  * **artifactregistry:** Update the api
  * **assuredworkloads:** Update the api
  * **batch:** Update the api
  * **beyondcorp:** Update the api
  * **bigquerydatatransfer:** Update the api
  * **bigqueryreservation:** Update the api
  * **bigquery:** Update the api
  * **bigtableadmin:** Update the api
  * **chat:** Update the api
  * **chromemanagement:** Update the api
  * **cloudasset:** Update the api
  * **cloudbuild:** Update the api
  * **cloudchannel:** Update the api
  * **clouddeploy:** Update the api
  * **cloudfunctions:** Update the api
  * **cloudresourcemanager:** Update the api
  * **cloudsearch:** Update the api
  * **cloudtasks:** Update the api
  * **composer:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **contactcenteraiplatform:** Update the api
  * **contactcenterinsights:** Update the api
  * **containeranalysis:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **contentwarehouse:** Update the api
  * **datacatalog:** Update the api
  * **dataflow:** Update the api
  * **dataform:** Update the api
  * **datafusion:** Update the api
  * **datamigration:** Update the api
  * **dataplex:** Update the api
  * **datastream:** Update the api
  * **dfareporting:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **dlp:** Update the api
  * **documentai:** Update the api
  * **drive:** Update the api
  * **fcm:** Update the api
  * **file:** Update the api
  * **firebaseappcheck:** Update the api
  * **firebaseappdistribution:** Update the api
  * **firebasehosting:** Update the api
  * **firestore:** Update the api
  * **gkehub:** Update the api
  * **healthcare:** Update the api
  * **iam:** Update the api
  * **identitytoolkit:** Update the api
  * **integrations:** Update the api
  * **managedidentities:** Update the api
  * **metastore:** Update the api
  * **migrationcenter:** Update the api
  * **networkconnectivity:** Update the api
  * **networksecurity:** Update the api
  * **networkservices:** Update the api
  * **ondemandscanning:** Update the api
  * **osconfig:** Update the api
  * **paymentsresellersubscription:** Update the api
  * **playdeveloperreporting:** Update the api
  * **playintegrity:** Update the api
  * **privateca:** Update the api
  * **pubsub:** Update the api
  * **recaptchaenterprise:** Update the api
  * **retail:** Update the api
  * **run:** Update the api
  * **script:** Update the api
  * **searchads360:** Update the api
  * **securitycenter:** Update the api
  * **serviceusage:** Update the api
  * **spanner:** Update the api
  * **speech:** Update the api
  * **sqladmin:** Update the api
  * **storagetransfer:** Update the api
  * **streetviewpublish:** Update the api
  * **testing:** Update the api
  * **tpu:** Update the api
  * **translate:** Update the api
  * **verifiedaccess:** Update the api
  * **vmmigration:** Update the api
  * **webfonts:** Update the api
  * **workloadmanager:** Update the api
  * **workstations:** Update the api
  * **youtube:** Update the api
  * Dead link to WebTest fixed in README. (#2127) (39e19d6)
* Thu May 11 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.86.0
  * **analyticsadmin:** Update the api
  * **apigee:** Update the api
  * **assuredworkloads:** Update the api
  * **beyondcorp:** Update the api
  * **bigquery:** Update the api
  * **certificatemanager:** Update the api
  * **chromemanagement:** Update the api
  * **cloudbuild:** Update the api
  * **cloudfunctions:** Update the api
  * **cloudkms:** Update the api
  * **cloudresourcemanager:** Update the api
  * **compute:** Update the api
  * **container:** Update the api
  * **contentwarehouse:** Update the api
  * **dataform:** Update the api
  * **datamigration:** Update the api
  * **discoveryengine:** Update the api
  * **file:** Update the api
  * **firestore:** Update the api
  * **gkehub:** Update the api
  * **identitytoolkit:** Update the api
  * **integrations:** Update the api
  * **managedidentities:** Update the api
  * **networksecurity:** Update the api
  * **retail:** Update the api
  * **run:** Update the api
  * **sqladmin:** Update the api
  * **tpu:** Update the api
  * **vault:** Update the api
  * **workloadmanager:** Update the api
  * **workstations:** Update the api
- from version 2.85.0
  * **adexperiencereport:** Update the api
  * **analyticsadmin:** Update the api
  * **androidpublisher:** Update the api
  * **assuredworkloads:** Update the api
  * **batch:** Update the api
  * **cloudresourcemanager:** Update the api
  * **cloudsupport:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **container:** Update the api
  * **contentwarehouse:** Update the api
  * **networkservices:** Update the api
  * **privateca:** Update the api
  * **recaptchaenterprise:** Update the api
  * **retail:** Update the api
  * **searchads360:** Update the api
  * **securitycenter:** Update the api
  * **servicemanagement:** Update the api
  * **serviceusage:** Update the api
  * **spanner:** Update the api
  * **tagmanager:** Update the api
  * **translate:** Update the api
  * **vmmigration:** Update the api
  * **workflowexecutions:** Update the api
  * **workflows:** Update the api
- from version 2.84.0
  * **advisorynotifications:** Update the api
  * **chromepolicy:** Update the api
  * **civicinfo:** Update the api
  * **cloudsearch:** Update the api
  * **cloudsupport:** Update the api
  * **compute:** Update the api
  * **contactcenterinsights:** Update the api
  * **containeranalysis:** Update the api
  * **container:** Update the api
  * **content:** Update the api
  * **datamigration:** Update the api
  * **dialogflow:** Update the api
  * **drivelabels:** Update the api
  * **file:** Update the api
  * **healthcare:** Update the api
  * **migrationcenter:** Update the api
  * **networkservices:** Update the api
  * **ondemandscanning:** Update the api
  * **playdeveloperreporting:** Update the api
  * **policysimulator:** Update the api
  * **recaptchaenterprise:** Update the api
  * **searchads360:** Update the api
  * **securitycenter:** Update the api
  * **serviceconsumermanagement:** Update the api
  * **servicenetworking:** Update the api
  * **serviceusage:** Update the api
  * **tpu:** Update the api
  * **transcoder:** Update the api
  * **translate:** Update the api
  * **vmmigration:** Update the api
  * **workflows:** Update the api
- from version 2.83.0
  * **analyticshub:** Update the api
  * **appengine:** Update the api
  * **bigqueryreservation:** Update the api
  * **bigquery:** Update the api
  * **cloudchannel:** Update the api
  * **clouddeploy:** Update the api
  * **cloudidentity:** Update the api
  * **composer:** Update the api
  * **connectors:** Update the api
  * **contentwarehouse:** Update the api
  * **datacatalog:** Update the api
  * **dataflow:** Update the api
  * **datafusion:** Update the api
  * **dataplex:** Update the api
  * **dataproc:** Update the api
  * **dfareporting:** Update the api
  * **discoveryengine:** Update the api
  * **dlp:** Update the api
  * **drivelabels:** Update the api
  * **eventarc:** Update the api
  * **gkehub:** Update the api
  * **iam:** Update the api
  * **identitytoolkit:** Update the api
  * **metastore:** Update the api
  * **migrationcenter:** Update the api
  * **monitoring:** Update the api
  * **networksecurity:** Update the api
  * **playdeveloperreporting:** Update the api
  * **recaptchaenterprise:** Update the api
  * **retail:** Update the api
  * **securitycenter:** Update the api
  * **servicedirectory:** Update the api
  * **vmmigration:** Update the api
* Sun Mar 26 2023 Dirk Müller <dmueller@suse.com>
- update to 2.82.0:
  * **analyticsadmin:** Update the api
  * **androiddeviceprovisioning:** Update the api
  * **assuredworkloads:** Update the api
  * **calendar:** Update the api
  * **chromepolicy:** Update the api
  * **clouddeploy:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **contactcenteraiplatform:** Update the api
  * **contactcenterinsights:** Update the api
  * **dataform:** Update the api
  * **datamigration:** Update the api
  * **discoveryengine:** Update the api
  * **drivelabels:** Update the api
  * **firestore:** Update the api
  * **metastore:** Update the api
  * **networkservices:** Update the api
  * **ondemandscanning:** Update the api
  * **orgpolicy:** Update the api
  * **playdeveloperreporting:** Update the api
  * **prod_tt_sasportal:** Update the api
  * **retail:** Update the api
  * **storage:** Update the api
  * **webrisk:** Update the api
* Fri Mar  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.80.0
  * **analyticsadmin:** Update the api
  * **analyticshub:** Update the api
  * **bigquery:** Update the api
  * **chat:** Update the api
  * **chromemanagement:** Update the api
  * **chromepolicy:** Update the api
  * **cloudchannel:** Update the api
  * **cloudfunctions:** Update the api
  * **cloudsearch:** Update the api
  * **compute:** Update the api
  * **connectors:** Update the api
  * **containeranalysis:** Update the api
  * **contentwarehouse:** Update the api
  * **datamigration:** Update the api
  * **dataplex:** Update the api
  * **dataproc:** Update the api
  * **dialogflow:** Update the api
  * **firestore:** Update the api
  * **gkehub:** Update the api
  * **identitytoolkit:** Update the api
  * **logging:** Update the api
  * **monitoring:** Update the api
  * **policysimulator:** Update the api
  * **recaptchaenterprise:** Update the api
  * **sasportal:** Update the api
  * **servicedirectory:** Update the api
  * **servicemanagement:** Update the api
  * **tpu:** Update the api
  * **transcoder:** Update the api
  * **vmmigration:** Update the api
  * **workstations:** Update the api
- from version 2.79.0
  * **alertcenter:** Update the api
  * **androidenterprise:** Update the api
  * **baremetalsolution:** Update the api
  * **batch:** Update the api
  * **chat:** Update the api
  * **chromemanagement:** Update the api
  * **cloudsearch:** Update the api
  * **compute:** Update the api
  * **content:** Update the api
  * **drive:** Update the api
  * **healthcare:** Update the api
  * **logging:** Update the api
  * **monitoring:** Update the api
  * **networksecurity:** Update the api
  * **ondemandscanning:** Update the api
  * **paymentsresellersubscription:** Update the api
  * **privateca:** Update the api
  * **redis:** Update the api
  * **safebrowsing:** Update the api
  * **serviceconsumermanagement:** Update the api
  * **servicecontrol:** Update the api
  * **servicenetworking:** Update the api
  * **serviceusage:** Update the api
- from version 2.78.0
  * **androidpublisher:** Update the api
  * **appengine:** Update the api
  * **artifactregistry:** Update the api
  * **baremetalsolution:** Update the api
  * **beyondcorp:** Update the api
  * **books:** Update the api
  * **chromemanagement:** Update the api
  * **chromepolicy:** Update the api
  * **clouddeploy:** Update the api
  * **cloudsearch:** Update the api
  * **compute:** Update the api
  * **dataproc:** Update the api
  * **datastream:** Update the api
  * **dialogflow:** Update the api
  * **gkehub:** Update the api
  * **healthcare:** Update the api
  * **iam:** Update the api
  * **privateca:** Update the api
  * **prod_tt_sasportal:** Update the api
  * **retail:** Update the api
  * **run:** Update the api
  * **servicecontrol:** Update the api
- from version 2.77.0
  * **analyticsadmin:** Update the api
  * **apigeeregistry:** Update the api
  * **artifactregistry:** Update the api
  * **batch:** Update the api
  * **chromemanagement:** Update the api
  * **chromeuxreport:** Update the api
  * **cloudbilling:** Update the api
  * **cloudsearch:** Update the api
  * **connectors:** Update the api
  * **contactcenterinsights:** Update the api
  * **contentwarehouse:** Update the api
  * **dataform:** Update the api
  * **datamigration:** Update the api
  * **documentai:** Update the api
  * **firebasehosting:** Update the api
  * **firebase:** Update the api
  * **gkehub:** Update the api
  * **manufacturers:** Update the api
  * **metastore:** Update the api
  * **notebooks:** Update the api
  * **safebrowsing:** Update the api
  * **servicecontrol:** Update the api
  * **tpu:** Update the api
  * **workstations:** Update the api
- from version 2.76.0
  * **analyticsadmin:** Update the api
  * **container:** Update the api
  * **datacatalog:** Update the api
  * **identitytoolkit:** Update the api
  * **integrations:** Update the api
  * **monitoring:** Update the api
  * **recaptchaenterprise:** Update the api
- from version 2.75.0
  * **apigeeregistry:** Update the api
  * **batch:** Update the api
  * **bigqueryreservation:** Update the api
  * **chromemanagement:** Update the api
  * **cloudsearch:** Update the api
  * **compute:** Update the api
  * **contentwarehouse:** Update the api
  * **dataflow:** Update the api
  * **documentai:** Update the api
  * **file:** Update the api
  * **gkehub:** Update the api
  * **integrations:** Update the api
  * **mybusinessverifications:** Update the api
  * **retail:** Update the api
  * **sts:** Update the api
  * **testing:** Update the api
  * **workflowexecutions:** Update the api
  * **workstations:** Update the api
- from version 2.74.0
  * **analyticshub:** Update the api
  * **appengine:** Update the api
  * **baremetalsolution:** Update the api
  * **bigquery:** Update the api
  * **cloudbuild:** Update the api
  * **clouddeploy:** Update the api
  * **cloudidentity:** Update the api
  * **compute:** Update the api
  * **datacatalog:** Update the api
  * **dataplex:** Update the api
  * **datastore:** Update the api
  * **displayvideo:** Update the api
  * **firebase:** Update the api
  * **firestore:** Update the api
  * **gkehub:** Update the api
  * **identitytoolkit:** Update the api
  * **integrations:** Update the api
  * **kmsinventory:** Update the api
  * **orgpolicy:** Update the api
  * **pubsub:** Update the api
  * **retail:** Update the api
  * **run:** Update the api
  * **servicenetworking:** Update the api
  * **androidpublisher:** Update the api
- from version 2.73.0
  * **admob:** Update the api
  * **androidenterprise:** Update the api
  * **appengine:** Update the api
  * **batch:** Update the api
  * **cloudtasks:** Update the api
  * **compute:** Update the api
  * **content:** Update the api
  * **dataform:** Update the api
  * **datamigration:** Update the api
  * **datastore:** Update the api
  * **dialogflow:** Update the api
  * **discoveryengine:** Update the api
  * **documentai:** Update the api
  * **firestore:** Update the api
  * **managedidentities:** Update the api
  * **metastore:** Update the api
  * **playdeveloperreporting:** Update the api
  * **recommender:** Update the api
  * **streetviewpublish:** Update the api
  * **translate:** Update the api
  * **vmmigration:** Update the api
  * **workstations:** Update the api
- from version 2.72.0
  * **admin:** Update the api
  * **baremetalsolution:** Update the api
  * **blogger:** Update the api
  * **chat:** Update the api
  * **chromemanagement:** Update the api
  * **chromepolicy:** Update the api
  * **cloudidentity:** Update the api
  * **container:** Update the api
  * **contentwarehouse:** Update the api
  * **datacatalog:** Update the api
  * **dataflow:** Update the api
  * **datapipelines:** Update the api
  * **dataplex:** Update the api
  * **dialogflow:** Update the api
  * **displayvideo:** Update the api
  * **file:** Update the api
  * **integrations:** Update the api
  * **playintegrity:** Update the api
  * **prod_tt_sasportal:** Update the api
  * **run:** Update the api
  * **sasportal:** Update the api
  * **texttospeech:** Update the api
  * **bigquery:** Update the api
- from version 2.71.0
  * **accesscontextmanager:** Update the api
  * **alertcenter:** Update the api
  * **androidenterprise:** Update the api
  * **apigee:** Update the api
  * **batch:** Update the api
  * **clouddeploy:** Update the api
  * **compute:** Update the api
  * **container:** Update the api
  * **contentwarehouse:** Update the api
  * **datafusion:** Update the api
  * **datamigration:** Update the api
  * **datapipelines:** Update the api
  * **dataplex:** Update the api
  * **dataproc:** Update the api
  * **datastream:** Update the api
  * **firestore:** Update the api
  * **gmail:** Update the api
  * **notebooks:** Update the api
  * **retail:** Update the api
  * **speech:** Update the api
  * **texttospeech:** Update the api
  * **workloadmanager:** Update the api
- Drop patch to disable oauth2client tests, fixed upstream
  * opensuse-remove-oauth2client-tests.patch
* Thu Jan  5 2023 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.70.0
  * Features
  appengine: update the api https://togithub.com/googleapis/google-api-python-client/commit/f3ae3793e74aae883aa8f3bca7d2d75227c99cbd (1506e28)
  bigquery: update the api https://togithub.com/googleapis/google-api-python-client/commit/9d8a28de9f2709a066cc62765132688f5a4eeba3 (1506e28)
  chat: update the api https://togithub.com/googleapis/google-api-python-client/commit/4b6ec2a405226f54a846e820be38c4be7e161df3 (1506e28)
  cloudbilling: update the api https://togithub.com/googleapis/google-api-python-client/commit/6de2af2c211a03d3f9443a89f222c1953d6bec9b (1506e28)
  cloudchannel: update the api https://togithub.com/googleapis/google-api-python-client/commit/bfbc1b18e9676ab2a7ef322c9ae2ff40bfc0c05e (1506e28)
  compute: update the api https://togithub.com/googleapis/google-api-python-client/commit/3ad8d540283d6153aeb7e7e5da043515fdd8feae (1506e28)
  connectors: update the api https://togithub.com/googleapis/google-api-python-client/commit/632cba551d23e3ac8c9044c56f1e3ebbce77ba1c (1506e28)
  contactcenterinsights: update the api https://togithub.com/googleapis/google-api-python-client/commit/6e512d6e138192e0312e44534b7904e95c36d0fe (1506e28)
  container: update the api https://togithub.com/googleapis/google-api-python-client/commit/05c853aec288828267afb32571d7f5ad8ac97cdf (1506e28)
  contentwarehouse: update the api https://togithub.com/googleapis/google-api-python-client/commit/720850e6a8a7cf0cd96170a3b82da993c2967b26 (1506e28)
  dataflow: update the api https://togithub.com/googleapis/google-api-python-client/commit/1b55a02805496e9431dbf173221958419400f905 (1506e28)
  dataproc: update the api https://togithub.com/googleapis/google-api-python-client/commit/952d0d1df1ce352ec5d53d9d2eb4fa07629d3c62 (1506e28)
  documentai: update the api https://togithub.com/googleapis/google-api-python-client/commit/9e0a2601bc52633ff3e3f70800977724fd1f7e0b (1506e28)
  gkehub: update the api https://togithub.com/googleapis/google-api-python-client/commit/e7a24b27433543dc8afd609bf6340a219456deef (1506e28)
  ids: update the api https://togithub.com/googleapis/google-api-python-client/commit/d7ca9ebf543d4cb3dbfae00a58862c7300466741 (1506e28)
  metastore: update the api https://togithub.com/googleapis/google-api-python-client/commit/23800233fe99f56885846fdcd927801b5641b6d3 (1506e28)
  networksecurity: update the api https://togithub.com/googleapis/google-api-python-client/commit/5cd2d575dc6b58695c3c3f3d32424949f2189f0f (1506e28)
  pubsublite: update the api https://togithub.com/googleapis/google-api-python-client/commit/ddc2cac9d91b7eb18421695895b41965c2658ac2 (1506e28)
  recaptchaenterprise: update the api https://togithub.com/googleapis/google-api-python-client/commit/85bf9110ba2ab06d6cc22e8b6c4b7b74309ea0fd (1506e28)
  servicenetworking: update the api https://togithub.com/googleapis/google-api-python-client/commit/310a96ffbd7672f55acc62a129f54b98b46506d9 (1506e28)
  sts: update the api https://togithub.com/googleapis/google-api-python-client/commit/e5219026edb8f430f68775cf96e0195a39e1a613 (1506e28)
  workflowexecutions: update the api https://togithub.com/googleapis/google-api-python-client/commit/3ff77236759bf338f5f295ae0e7453184bfbd745 (1506e28)
* Wed Dec 14 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python_module macro definition
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.69.0
  * Features
  analyticsadmin: update the api https://togithub.com/googleapis/google-api-python-client/commit/1277148ed4bb16c03802a6d11bb15ab138bf6c19 (fa65fca)
  assuredworkloads: update the api https://togithub.com/googleapis/google-api-python-client/commit/0777a539623f6a0e5c0ee8a0014c49797e14a826 (fa65fca)
  baremetalsolution: update the api https://togithub.com/googleapis/google-api-python-client/commit/21f9266331d46ae55a4749d485d5937797d75c03 (fa65fca)
  batch: update the api https://github.com/googleapis/google-api-python-client/commit/5b1f5b056998a149f675ecdf8794563a9e9460fc (f6e9d38)
  chat: update the api https://togithub.com/googleapis/google-api-python-client/commit/42d7975db499e1298a45b5d7ea086dddbfd3e5ec (fa65fca)
  cloudbuild: update the api https://github.com/googleapis/google-api-python-client/commit/ef1b5979776140ff203a53e82d0427ebda0112c0 (f6e9d38)
  cloudfunctions: update the api https://togithub.com/googleapis/google-api-python-client/commit/27456f04a82bd30a897822da45adba98b00d0b73 (fa65fca)
  cloudsearch: update the api https://togithub.com/googleapis/google-api-python-client/commit/2ebbbba9e1ceac8db6b3a90e56d00bad3c6183c5 (fa65fca)
  cloudsupport: update the api https://togithub.com/googleapis/google-api-python-client/commit/660300bb6094cdafa87016f16becc956489d723f (fa65fca)
  composer: update the api https://togithub.com/googleapis/google-api-python-client/commit/b223e46fa38d9cabcf81b66ca78e9b1d4e88c01b (fa65fca)
  compute: update the api https://github.com/googleapis/google-api-python-client/commit/23ca08a7e9717d0aefff49823f4d594ed118ec25 (f6e9d38)
  compute: update the api https://togithub.com/googleapis/google-api-python-client/commit/2a5e985835d9e6a6eff7d88c2d8aac08fa4677df (fa65fca)
  content: update the api https://togithub.com/googleapis/google-api-python-client/commit/93233da7ebde3542aaa004402c77bc19e6c919be (fa65fca)
  dataplex: update the api https://togithub.com/googleapis/google-api-python-client/commit/714d395fa712c56f1d207e4408ca1a252fd3d162 (fa65fca)
  dialogflow: update the api https://togithub.com/googleapis/google-api-python-client/commit/1d14a2f69b29855ec25b488babfbceb0609a519c (fa65fca)
  displayvideo: update the api https://togithub.com/googleapis/google-api-python-client/commit/1a3f64b4fd8e4f1774e1c6e6a70ad91a5a550590 (fa65fca)
  gamesConfiguration: update the api https://togithub.com/googleapis/google-api-python-client/commit/5e1872ea1691596119064e2d09043a99c15adac3 (fa65fca)
  metastore: update the api https://togithub.com/googleapis/google-api-python-client/commit/eba8d4f0e129812a600e4e8e6c33f4ab88c95180 (fa65fca)
  monitoring: update the api https://github.com/googleapis/google-api-python-client/commit/cb568e1f19afa239b1b5dfbc1bc14554c130c15c (f6e9d38)
  networkmanagement: update the api https://togithub.com/googleapis/google-api-python-client/commit/c65d33b8ca6b2aa014bc39bd4ca32ed1e9ebd96c (fa65fca)
  paymentsresellersubscription: update the api https://togithub.com/googleapis/google-api-python-client/commit/fd60e1157653d8b018ac093b01a32d3434148df4 (fa65fca)
  securitycenter: update the api https://togithub.com/googleapis/google-api-python-client/commit/c0c746a361421b6d250817f4d397d2c34dc2c4e9 (fa65fca)
  servicemanagement: update the api https://togithub.com/googleapis/google-api-python-client/commit/e3f20cd1141dd5ca47b2323eb0fa029e255c78ec (fa65fca)
  spanner: update the api https://togithub.com/googleapis/google-api-python-client/commit/c2007c17ae0eb31027417903a034dbc98eade638 (fa65fca)
  storagetransfer: update the api https://github.com/googleapis/google-api-python-client/commit/76c66c741eef394307e290ccad3dde13c950d2cf (f6e9d38)
  texttospeech: update the api https://togithub.com/googleapis/google-api-python-client/commit/bb64e3c504126472671203b1affec77396db89e7 (fa65fca)
  vmmigration: update the api https://togithub.com/googleapis/google-api-python-client/commit/3e1a2c94e7c20c7fef3f746bf40f74c06b7c2e29 (fa65fca)
  * Bug Fixes
  Fix media upload URI when API endpoint is overridden with client_opions.api_endpoint (#1992) (d0f8a05)
* Mon Dec  5 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.68.0:
  * Add support for Python 3.11 (#1973)
  * **androidmanagement:** update the api (9b5767f)
  * **chat:** update the api (9b5767f)
  * **chromemanagement:** update the api (03f4753)
  * **cloudasset:** update the api (9b5767f)
  * **cloudsearch:** update the api (9b5767f)
  * **composer:** update the api (9b5767f)
  * **contactcenterinsights:** update the api (9b5767f)
  * **container:** update the api (9b5767f)
  * **datapipelines:** update the api  (9b5767f)
  * **dataplex:** update the api (9b5767f)
  * **dns:** update the api (9b5767f)
  * **documentai:** update the api (9b5767f)
  * **securitycenter:** update the api (9b5767f)
  * **serviceconsumermanagement:** update the api (9b5767f)
  * **servicenetworking:** update the api (9b5767f)
  * **serviceusage:** update the api (9b5767f)
  * **sqladmin:** update the api (03f4753)
  * **testing:** update the api (9b5767f)
* Wed Nov 30 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.66.0:
  * **alertcenter:** update the api
  * **androiddeviceprovisioning:** update the api
  * **androidpublisher:** update the api
  * **appengine:** update the api
  * **artifactregistry:** update the api
  * **assuredworkloads:** update the api
  * **assuredworkloads:** update the api
  * **baremetalsolution:** update the api
  * **beyondcorp:** update the api
  * **bigquery:** update the api
  * **bigtableadmin:** update the api
  * **chat:** update the api
  * **chat:** update the api
  * **chromepolicy:** update the api
  * **cloudbuild:** update the api
  * **cloudfunctions:** update the api
  * **cloudsearch:** update the api
  * **cloudtasks:** update the api
  * **composer:** update the api
  * **compute:** update the api
  * **compute:** update the api
  * **connectors:** update the api
  * **containeranalysis:** update the api
  * **content:** update the api
  * **contentwarehouse:** update the api
  * **contentwarehouse:** update the api
  * **datacatalog:** update the api
  * **dataplex:** update the api
  * **dataplex:** update the api
  * **dataproc:** update the api
  * **dataproc:** update the api
  * **datastore:** update the api
  * **dialogflow:** update the api
  * **displayvideo:** update the api
  * **documentai:** update the api
  * **doubleclicksearch:** update the api
  * **drivelabels:** update the api
  * **firestore:** update the api
  * **gkehub:** update the api
  * **healthcare:** update the api
  * **integrations:** update the api
  * **managedidentities:** update the api
  * **managedidentities:** update the api
  * **metastore:** update the api
  * **monitoring:** update the api
  * **networkconnectivity:** update the api
  * **playintegrity:** update the api
  * **redis:** update the api
  * **retail:** update the api
  * **retail:** update the api
  * **run:** update the api
  * **run:** update the api
  * **servicecontrol:** update the api
  * **servicedirectory:** update the api
  * **speech:** update the api
  * **sqladmin:** update the api
  * **tagmanager:** update the api
  * **translate:** update the api
  * Fix a typo in UPGRADING.md related to static_discovery (#1956) (bc03ac6)
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 2.65.0:
  Features
  * alertcenter: update the api https://togithub.com/googleapis/google-api-python-client/commit/99b94eeb1cf0f695d921ac1d9081c0841f6b1693 (5d54a7d)
  * analyticsadmin: update the api https://togithub.com/googleapis/google-api-python-client/commit/41818c6eb42aa3551fc2a326208f9cc083cb1953 (7110d89)
  * assuredworkloads: update the api https://togithub.com/googleapis/google-api-python-client/commit/9756c064a5cff42e367677216c48ff6649817dd5 (5d54a7d)
  * chat: update the api https://togithub.com/googleapis/google-api-python-client/commit/6dce01ba90d86496038bad226a14a9d714fb6e37 (7110d89)
  * chromepolicy: update the api https://togithub.com/googleapis/google-api-python-client/commit/180883247dcfcd777de04758a7928ca84e2764da (7110d89)
  * cloudbuild: update the api https://togithub.com/googleapis/google-api-python-client/commit/555317bfb60133f8ff82d4ac28651631404980d4 (5d54a7d)
  * cloudsearch: update the api https://togithub.com/googleapis/google-api-python-client/commit/2717d97f6ccd16b03f70adbb317fb330f74f3e2d (5d54a7d)
  * containeranalysis: update the api https://togithub.com/googleapis/google-api-python-client/commit/322df84348b8765bc6dce442c5d03209963a0e6b (5d54a7d)
  * container: update the api https://togithub.com/googleapis/google-api-python-client/commit/ea99aeeb561642071866b71f54ae84be95ae5bcc (5d54a7d)
  * dlp: update the api https://togithub.com/googleapis/google-api-python-client/commit/618362554c62d453579ff52933234a93ea5dfae3 (5d54a7d)
  * doubleclicksearch: update the api https://togithub.com/googleapis/google-api-python-client/commit/1e7db3e4969b55ecf98bbb78d3edc53f4bf08a15 (7110d89)
  * firebase: update the api https://togithub.com/googleapis/google-api-python-client/commit/569cb7e362206b8a7563b689ccd720ed29259997 (7110d89)
  * notebooks: update the api https://togithub.com/googleapis/google-api-python-client/commit/9ff1945acf3a74221759c2ceb9eb9a22c22b7c09 (5d54a7d)
  * retail: update the api https://togithub.com/googleapis/google-api-python-client/commit/32de4a02de0fd9e11755418f13c623f5b5c56674 (7110d89)
  * securitycenter: update the api https://togithub.com/googleapis/google-api-python-client/commit/b1c67c818d662fe97e82b000931be739766fbe55 (7110d89)
  * tagmanager: update the api https://togithub.com/googleapis/google-api-python-client/commit/188cd231f843aafb1c49cafe64052ec190e477a8 (5d54a7d)
  * verifiedaccess: update the api https://togithub.com/googleapis/google-api-python-client/commit/e2dccf7393b2e15986b1ba88ea6aa2b4f621dc17 (7110d89)
  Bug Fixes
  * prod_tt_sasportal: update the api https://togithub.com/googleapis/google-api-python-client/commit/9000eddf5e2e22242ebc94cb0af60363ff5c41df (5d54a7d)
  * sasportal: update the api https://togithub.com/googleapis/google-api-python-client/commit/36e8c8bc1b9cb3bbab1abdb2936d7a9cc9cea87a (7110d89)
  * smartdevicemanagement: update the api https://togithub.com/googleapis/google-api-python-client/commit/f7cc8d243a3c6b16cdf7aafae285b2efbb65d1fc (7110d89)
* Fri Oct 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.64.0:
  * **analyticsadmin:** update the api
  * **assuredworkloads:** update the api
  * **beyondcorp:** update the api
  * **bigquery:** update the api
  * **certificatemanager:** update the api
  * **chromemanagement:** update the api
  * **chromepolicy:** update the api
  * **cloudasset:** update the api
  * **cloudidentity:** update the api
  * **cloudsearch:** update the api
  * **cloudtasks:** update the api
  * **compute:** update the api
  * **containeranalysis:** update the api
  * **dataflow:** update the api
  * **documentai:** update the api
  * **driveactivity:** update the api
  * **firebasestorage:** update the api
  * **monitoring:** update the api
  * **paymentsresellersubscription:** update the api
  * **playintegrity:** update the api
  * **recommender:** update the api
  * **retail:** update the api
  * **spanner:** update the api
- from version 2.63.0:
  * **admin:** update the api
  * **adsense:** update the api
  * **androidpublisher:** update the api
  * **assuredworkloads:** update the api
  * **baremetalsolution:** update the api
  * **bigquery:** update the api
  * **chromeuxreport:** update the api
  * **cloudbuild:** update the api
  * **clouddeploy:** update the api
  * **cloudkms:** update the api
  * **composer:** update the api
  * **compute:** update the api
  * **dataplex:** update the api
  * **dfareporting:** update the api
  * **dns:** update the api
  * **documentai:** update the api
  * **firestore:** update the api
  * **healthcare:** update the api
  * **identitytoolkit:** update the api
  * **language:** update the api
  * **monitoring:** update the api
  * **networkconnectivity:** update the api
  * **networkmanagement:** update the api
  * **ondemandscanning:** update the api
  * **recommender:** update the api
  * **run:** update the api
  * **securitycenter:** update the api
  * **youtube:** update the api
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 2.62.0:
  * **analyticshub:** update the api
  * **artifactregistry:** update the api
  * **assuredworkloads:** update the api
  * **bigquery:** update the api
  * **chromemanagement:** update the api
  * **chromepolicy:** update the api
  * **clouddeploy:** update the api
  * **cloudsearch:** update the api
  * **container:** update the api
  * **dataflow:** update the api
  * **dlp:** update the api
  * **documentai:** update the api
  * **gkehub:** update the api
  * **identitytoolkit:** update the api
  * **manufacturers:** update the api
  * **securitycenter:** update the api
  * **spanner:** update the api
  * **vmmigration:** update the api
- from version 2.61.0:
  * **androidpublisher:** update the api
  * **assuredworkloads:** update the api
  * **bigquery:** update the api
  * **cloudbuild:** update the api
  * **clouddeploy:** update the api
  * **cloudsearch:** update the api
  * **cloudtasks:** update the api
  * **compute:** update the api
  * **containeranalysis:** update the api
  * **content:** update the api
  * **dataflow:** update the api
  * **dataproc:** update the api
  * **dns:** update the api
  * **firebase:** update the api
  * **orgpolicy:** update the api
  * **paymentsresellersubscription:** update the api
  * **retail:** update the api
  * **sqladmin:** update the api
  * **storagetransfer:** update the api
  * **tpu:** update the api
  * **translate:** update the api
  * **workflowexecutions:** update the api
  * **tagmanager:** update the api
* Mon Sep 12 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.60.0:
  * **apigeeregistry:** update the api
  * **baremetalsolution:** update the api
  * **bigquery:** update the api
  * **chat:** update the api
  * **cloudidentity:** update the api
  * **compute:** update the api
  * **datacatalog:** update the api
  * **dataproc:** update the api
  * **dialogflow:** update the api
  * **documentai:** update the api
  * **gkehub:** update the api
  * **identitytoolkit:** update the api
  * **managedidentities:** update the api
  * **playintegrity:** update the api
  * **servicemanagement:** update the api
  * **testing:** update the api
  * **adsense:** update the api
  * **policysimulator:** update the api
  * **samples:** Replace APPENGINE_RUNTIME with GAE_ENV (#1893)
- from version 2.59.0:
  * **analyticsadmin:** update the api
  * **analyticsdata:** update the api
  * **assuredworkloads:** update the api
  * **baremetalsolution:** update the api
  * **cloudbuild:** update the api
  * **compute:** update the api
  * **datamigration:** update the api
  * **datastream:** update the api
  * **dialogflow:** update the api
  * **documentai:** update the api
  * **iap:** update the api
  * **monitoring:** update the api
  * **mybusinessplaceactions:** update the api
  * **paymentsresellersubscription:** update the api
  * **serviceconsumermanagement:** update the api
  * **servicenetworking:** update the api
  * **serviceusage:** update the api
  * **speech:** update the api
  * **firebase:** update the api
- from verson 2.58.0:
  * **adsense:** update the api
  * **apigee:** update the api
  * **chromepolicy:** update the api
  * **cloudsearch:** update the api
  * **compute:** update the api
  * **dataflow:** update the api
  * **dataproc:** update the api
  * **dlp:** update the api
  * **documentai:** update the api
  * **drive:** update the api
  * **firebase:** update the api
  * **gkehub:** update the api
  * **managedidentities:** update the api
  * **networkmanagement:** update the api
  * **orgpolicy:** update the api
  * **playintegrity:** update the api
  * **retail:** update the api
  * **secretmanager:** update the api
  * **serviceconsumermanagement:** update the api
  * **servicemanagement:** update the api
  * **servicenetworking:** update the api
  * **serviceusage:** update the api
  * **tagmanager:** update the api
  * **transcoder:** update the api
  * **dfareporting:** update the api
- from version 2.57.0:
  * **admin:** update the api
  * **apigee:** update the api
  * **artifactregistry:** update the api
  * **bigquery:** update the api
  * **certificatemanager:** update the api
  * **cloudidentity:** update the api
  * **cloudsearch:** update the api
  * **compute:** update the api
  * **connectors:** update the api
  * **containeranalysis:** update the api
  * **content:** update the api
  * **dataflow:** update the api
  * **documentai:** update the api
  * **gkehub:** update the api
  * **manufacturers:** update the api
  * **mybusinessplaceactions:** update the api
  * **run:** update the api
  * **securitycenter:** update the api
  * **sqladmin:** update the api
  * **toolresults:** update the api
  * **translate:** update the api
  * **vision:** update the api
* Mon Aug 15 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.56.0:
  * * : update the api
  * deps: require google-auth 1.19.0 (#1824) (7f478ae)
  * deps: require python 3.7+
  * test: Switch to unittest.mock
- Refresh patches.
* Thu Apr 14 2022 Ben Greiner <code@bnavigator.de>
- Update to 2.44.0
  * * : update the api
  * deps: require google-api-core>=1.31.5, >=2.3.2 (#1715) (8308e5d)
  * remove adsense.v1.4.json (#1616) (5d3e588)
  * expose library version at googleapiclient.version (#1623) (83db1d7)
  * deps: require uritemplate 3.0.1 (#1629) (1c4cfdb)
- Do not test deprecated oauth2client anymore:
  * add opensuse-remove-oauth2client-tests.patch
* Wed Dec  1 2021 Jan Baier <jbaier@suse.com>
- Update to 2.31.0:
  * MediaIoBaseDownload range header off-by-one (#1595) (4b73b2e)
- from version 2.28.0:
  * manage JSONDecodeError exception (#1574) (7d63027)
  * update thread_safety.md (#1568) (0b400f9)
- from version 2.26.1:
  * disable self signed jwt (#1566) (623a71e)
- from version 2.26.0:
  * add support for python 3.10 (#1557) (bcc507f)
- from version 2.25.0:
  * enable self signed jwt for service account credentials (#1553) (1fb3c8e)
- Drop python-google-api-python-client-no-unittest2.patch
* Mon Sep 13 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.20.0:
  * Adds support for errors.py to also use 'errors' for error_details (#1281) (a5d2081)
  * add status_code property on http error handling (#1185) (db2a766)
  * Change default of static_discovery when discoveryServiceUrl set (#1261) (3b4f2e2)
  * correct api version in oauth-installed.md (#1258) (d1a255f)
  * fix .close() (#1231) (a9583f7)
  * Resolve issue where num_retries would have no effect (#1244) (c518472)
  * Include discovery artifacts in published package (#1221) (ad618d0)
  * Require Python 3.6+
  * Add support for using static discovery documents (#1109) (32d1c59)
  * Update synth.py to copy discovery files from discovery-artifact-manager (#1104) (af918e8)
  * Catch ECONNRESET and other errors more reliably (#1147) (ae9cd99)
  * deps: add upper-bound google-auth dependency (#1180) (c687f42)
  * handle error on service not enabled (#1117) (c691283)
  * Improve support for error_details (#1126) (e6a1da3)
  * MediaFileUpload error if file does not exist (#1127) (2c6d029)
  * replace deprecated socket.error with OSError (#1161) (b7b9986)
  * Use logging level info when file_cache is not available (#1125) (0b32e69)
  * add httplib2 authorization to thread_safety (#1005) (205ae59), closes #808
  * Change error parsing to check for 'message' (#1083) (a341c5a), closes #1082
  * don't raise when downloading zero byte files (#1074) (86d8788)
- Refreshed python-google-api-python-client-no-unittest2.patch
* Mon Jul  5 2021 Martin Wilck <mwilck@suse.com>
- Update to version 1.12.8
  * add httplib2 authorization to thread_safety (#1005), closes #808
- from version 1.12.7
  * Update Webmasters API sample (#1092)
- from version 1.12.6
  * Dcoumentation fixes
- from version 1.12.5
  * don't raise when downloading zero byte files (#1074)
- from version 1.12.4
  * don't set content-range on empty uploads (#1070)
- from version 1.12.3
  * deps: update setup.py to install httplib2>=0.15.0 (#1050)
- from version 1.12.2
  * add method to close httplib2 connections (#1038), closes #618
- from version 1.12.1
  * deps: require six>=1.13.0 (#1030)
- from version 1.12.0
  * convert print statement to function (#988), closes #987
  * remove http from batch execute docs (#1003), closes #1002
* Thu Sep 10 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.11.0
  * add support for mtls env variables (#1008)
- from version 1.10.1
  * discovery uses V2 when version is None (#975), closes (#971)
  * fix deprecation warnings due to invalid escape sequences. (#996), closes (#995)
  * fix link to service accounts documentation (#986)
  * update generated docs (#981)
- from version 1.10.0
  * allow to use 'six.moves.collections_abc.Mapping' in 'client_options.from_dict()' (#943)
  * Build universal wheels (#948)
  * discovery supports retries (#967), closes (#848)
  * consolidating and updating the Contribution Guide (#964), closes (#963)
- from version 1.9.3
  * update GOOGLE_API_USE_MTLS values (#940)
- from version 1.9.2
  * bump api-core version (#936)
- from version 1.9.1
  * fix python-api-core dependency issue (#931)
- from version 1.9.0
  * add mtls feature (#917)
  * add templates for python samples projects (#506), (#924)
- Refresh patches for new version
  + python-google-api-python-client-no-unittest2.patch
- Update BuildRequires and Requires from setup.py
* Thu Jun 25 2020 pgajdos@suse.com
- so remove the dependency on unittest2 from BuildRequires, too
* Mon Jun  1 2020 pgajdos@suse.com
- version update to 1.8.4
  * don't try to import GAE API in other environments (#903) (09e6447)
  * the turn down date for global batch uri (#901) (6ddadd7)
  * downgrade repetitive logging calls to debug (#885) (3bf2781), closes #781
- added patches
  fix unittest2 seems to be fake dependency
  + python-google-api-python-client-no-unittest2.patch
* Mon May 11 2020 Matej Cepl <mcepl@suse.com>
- Update to 1.8.2:
  - Remove apiclient.__version__ gh#googleapis/googleapis#870
  - Adding ConnectionError to retry mechanism gh#googleapis/googleapis#558
  - replace '-' in method names with '_' gh#googleapis/google-api-python-client#863
- Add missing dependency on oauth2client.
- Fix filelist (no CHANGELOG anymore, missing README.md)
* Wed Apr  8 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.8.0
  * Add api endpoint override. (https://github.com/googleapis/google-api-python-client/pull/829)
  * Various small bugfixes.
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.7.11 bsc#1161898:
  * Various small bugfixes only
* Thu Mar 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.7.8:
  * bunch of small bugfixes
  * python2 exec prints warning now about deprecation
- Remove hidePythonDeps.patch does not make sense
- Add back unittest2 dep, upstream hardcoded it
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Aug 13 2018 mcepl@suse.com
- Remove dependency on unittest2
- Upgrade to 1.7.4: just series of minor bugfixes
* Thu May 31 2018 toddrme2178@gmail.com
- Add bug report about tests
* Tue May 29 2018 tbechtold@suse.com
- update to 1.6.7:
  - Make body optional for requests with no parameters. (#446)
  - Fix retying on socket.timeout. (#495)
  - Match travis matrix with tox testenv. (#498)
  - Remove oauth2client._helpers dependency. (#493)
  - Remove unused keyring test dependency. (#496)
  - discovery.py: remove unused oauth2client import. (#492)
  - Update README to reference GCP API client libraries. (#490)
  - Warn when constructing BatchHttpRequest using the legacy batch URI (#488)
  - Increase the default media chunksize to 100MB. (#482)
  - Remove unnecessary parsing of mime headers in HttpRequest.__init__ (#467)
  - Proactively refresh credentials when applying and treat a missing
    `access_token` as invalid. Note: This change reveals surprising behavior
    between default credentials and batches. If you allow
    `googleapiclient.discovery.build` to use default credentials *and* specify
    different credentials by providing `batch.execut()` with an explicit `http`
    argument, your individual requests will use the default credentials and
  * not* the credentials specified to the batch http. To avoid this, tell
    `build` explicitly not to use default credentials by specifying
    `build(..., http=httplib2.Http()`. (#469)
  - Remove mutual exclusivity check for developerKey and credentials (#465)
  - Handle unknown media length. (#406)
  - Handle variant error format gracefully. (#459)
  - Avoid testing against Django >= 2.0.0 on Python 2. (#460)
- Use %%license
* Sat Sep 30 2017 arun@gmx.de
- update to version 1.6.4:
  * Warn when google-auth credentials are used but
    google-auth-httplib2 isn't available. (#443)
- changes from version 1.6.3:
  * Add notification of maintenance mode to README. (#410)
  * Fix generation of methods with abnormal page token
    conventions. (#338)
  * Raise ValueError is credentials and developerKey are both
    specified. (#358)
  * Re-generate documentation. (#364, #373, #401)
  * Fix method signature documentation for multiline required
    parameters. (#374)
  * Fix ZeroDivisionError in MediaDownloadProgress.progress. (#377)
  * Fix dead link to WebTest in README. (#378)
  * Fix details missing in googleapiclient.errors.HttpError. (#412)
  * Don't treat httplib2.Credentials as oauth credentials. (#425)
  * Various fixes to the Django sample. (#413)
* Mon Jul 10 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Update source URL.
- Update to Version 1.6.2
  * Fixed a bug where application default credentials would still be used even
    when a developerKey was specified. (#347)
  * Official support for Python 3.5 and 3.6. (#341)
- Update to Version 1.6.1
  * Fixed a bug where using google-auth with scoped credentials would fail. (#328)
- Update to Version 1.6.0
  * Support for Python 2.6 has been dropped. (#319)
  * The credentials argument to discovery.build and discovery.build_from_document
    can be either oauth2client credentials or google-auth credentials. (#319)
  * discovery.build and discovery.build_from_document now unambiguously use the
    http argument to make all requests, including the request for the discovery
    document. (#319)
  * The http and credentials arguments to discovery.build and
    discovery.build_from_document are now mutually exclusive, eliminating a
    buggy edge case. (#319)
  * If neither http or credentials is specified to discovery.build and
    discovery.build_from_document, then Application Default Credentials will
    be used. The library prefers google-auth for this if it is available, but
    can also use oauth2client's implementation. (#319)
  * Fixed resumable upload failure when receiving a 308 response. (#312)
  * Clarified the support versions of Python 3. (#316)
- Update to Version 1.5.5
  * Allow explicit MIME type specification with media_mime_type keyword argument.
  * Fix unprintable representation of BatchError with default constructor. (#165)
  * Refresh all discovery docs, not just the preferred ones. (#298)
  * Update minimum httplib2 dependency to >=0.9.2.
* Thu Nov  3 2016 rjschwei@suse.com
- Fix description of -test sub-package
* Fri Oct 28 2016 rjschwei@suse.com
- Add missing runtime dependencies as requires
* Fri Oct 28 2016 lchiquitto@suse.de
- Use new package's name in -test sub-package requires
* Thu Oct 27 2016 rjschwei@suse.com
- Include in SLE 12 (FATE#321630, bsc#1002895)
* Tue Oct 18 2016 rjschwei@suse.com
- Renamed package to python-google-api-python-client
  * Conform with openSUSE/SUSE naming policy
* Tue Oct 18 2016 rjschwei@suse.com
- Upgrade to version 1.5.4 (bsc#1002895)
  * Properly handle errors when the API returns a mapping or sequence. (#289)
  * Upgrade to unified uritemplate 3.0.0. (#293)
  * Allow oauth2client 4.0.0, with the caveat that file-based discovery
    caching is disabled.
- From 1.5.2
  * Allow using oauth2client >= 1.5.0, < 4.0.0. (#265)
  * Fix project_id argument description. (#257)
  * Retry chunk uploaded on rate limit exceeded errors. (#255)
  * Obtain access token if necessary in BatchHttpRequest.execute(). (#232)
  * Warn when running tests using HttpMock without having a cache. (#261)
- From 1.5.1
  * Allow using versions of oauth2client < 2.0.0. (#197)
  * Check both current and new API discovery URL. (#202)
  * Retry http requests on connection errors and timeouts. (#218)
  * Retry http requests on rate limit responses. (#201)
  * Import guards for ssl (for Google App Engine). (#220)
  * Use named loggers instead of the root logger. (#206)
  * New search console example. (#212)
- From 1.5.0
  * Fix file stream recognition in Python 3 (#141)
  * Fix non-resumable binary uploads in Python 3 (#147)
  * Default to 'octet-stream' if mimetype detection fails (#157)
  * Handle SSL errors with retries (#160)
  * Fix incompatibility with oauth2client v2.0.0 (#182)
* Thu Nov 12 2015 rjschwei@suse.com
- Upgrade to version 1.4.2 (bsc#954690)
  * oauth2client is now a separate package python-oauth2client
  * Need to update this version as the previous embedded version for
    oauth2client lacks necessary features for google-cloud-sdk
  * remove patch no_embed_uritempl_dep.patch
  * add patch hidePythonDeps.patch
  * Add automatic caching for the discovery docs.
  - From 1.4.1
  * Add the googleapiclient.discovery.Resource.new_batch_http_request method.
  - From 1.4.0
  * Python 3 support.
  - From 1.3.2
  * Fix an infinite loop for downloading small files.
  * Fix a unicode error in error encoding.
  * Better handling of `content-length` in media requests.
  * Add support for methodPath entries containing colon.
  - From 1.3.1
  * Quick release for a fix around aliasing in v1.3.
  - From 1.3.0
  * Add support for the Google Application Default Credentials.
  * Require python 2.6 as a minimum version.
  * Update several API samples.
  * Finish splitting out oauth2client repo and update tests.
  * Various doc cleanup and bugfixes.
  * Two important notes:
  * We've added `googleapiclient` as the primary suggested import
    name, and kept `apiclient` as an alias, in order to have a more
    appropriate import name. At some point, we will remove `apiclient`
    as an alias.
  * Due to an issue around in-place upgrades for Python packages,
    it's not possible to do an upgrade from version 1.2 to 1.3. Instead,
    setup.py attempts to detect this and prevents it. Simply remove
    the previous version and reinstall to fix this.
* Tue Mar  4 2014 rschweikert@suse.com
- Fix dependency issue, do not include uritemplate, this is an
  independent upstream code stream
- Add patch no_embed_uritempl_dep.patch
* Thu Feb 13 2014 rschweikert@suse.com
- include in SLE 12 (FATE #316168)
* Wed Oct 30 2013 rschweikert@suse.com
- update to version 1.2
  * The use of the gflags library is now deprecated, and is no longer a
    dependency. If you are still using the oauth2client.tools.run() function
    then include gflags as a dependency of your application or switch to
    oauth2client.tools.run_flow.
  * Samples have been updated to use the new apiclient.sample_tools, and no
    longer use gflags.
  * Added support for the experimental Object Change Notification, as found in
    the Cloud Storage API.
  * The oauth2client App Engine decorators are now threadsafe.
  * Use the following redirects feature of httplib2 where it returns the
    ultimate URL after a series of redirects to avoid multiple hops for every
    resumable media upload request.
  * Updated AdSense Management API samples to V1.3
  * Add option to automatically retry requests.
  * Ability to list registered keys in multistore_file.
  * User-agent must contain (gzip).
  * The 'method' parameter for httplib2 is not positional. This would cause
    spurious warnings in the logging.
  * Making OAuth2Decorator more extensible. Fixes Issue 256.
  * Update AdExchange Buyer API examples to version v1.2.
* Tue Aug  6 2013 rschweikert@suse.com
- Initial build
